@@ -100,7 +100,7 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.13';
+    return '1.13.1';
   }
 
 
@@ -211,12 +211,12 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGEcommerceBase'=>'1.3.1',
+    return array('CGEcommerceBase'=>'1.2.4',
 		 'FrontEndUsers'=>'1.12.8',
-		 'CGExtensions'=>'1.25',
+		 'CGExtensions'=>'1.24',
 		 'CGSimpleSmarty'=>'1.3.1',
 		 'CMSMailer'=>'1.73.13',
-		 'CGPaymentGatewayBase'=>'1.0.11');
+		 'CGPaymentGatewayBase'=>'1.0.10');
   }
 
 
@@ -225,7 +225,7 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.9.2";
+    return "1.9.4";
   }
 	
 	
@@ -462,9 +462,6 @@ EOT;
 
     return FALSE;
   }
-
-  public function can_cache_output() { return FALSE; }
-
 } // class
 
 #
