@@ -73,18 +73,13 @@ else
 
 $this->SetPreference('admin_invoice_template',trim($params['admin_invoice_template']));
 $this->SetPreference('invoice_message',cms_html_entity_decode($params['invoice_message']));
-$this->SetPreference('allow_creditcard_entry',$params['allow_creditcard_entry']);
-$this->SetPreference('store_creditcard_data',$params['store_creditcard_data']);
-$this->SetPreference('store_creditcard_4digits',$params['store_creditcard_4digits']);
 $this->SetPreference('encryption_key',$params['encryption_key']);
 $this->SetPreference('billingpage',$params['billingpage']);
+$this->SetPreference('shippingpage',$params['shippingpage']);
 $this->SetPreference('confirmpage',$params['confirmpage']);
-$this->SetPreference('paymentpage',$params['paymentpage']);
 $this->SetPreference('invoicepage',$params['invoicepage']);
-$this->SetPreference('force_ssl',$params['force_ssl']);
 $this->SetPreference('gateway_description',$params['gateway_description']);
 $this->SetPreference('allow_anon_checkout',$params['allow_anon_checkout']);
-$this->SetPreference('allow_manual_checkout',$params['allow_manual_checkout']);
 
 $num = (int)$params['datastore_timeout'];
 $num = max(1,$num);
