@@ -34,19 +34,9 @@
 #-------------------------------------------------------------------------
 if( !isset($gCms) ) exit;
 
-//require_once(dirname(__FILE__).'/lib/class.orders_ops.php');
-
 //
 // Initialization
 //
-// redirect to https if required, include weird check for IIS. SjG
-if (orders_helper::creditcard_requires_ssl() &&
-    (! isset($_SERVER['HTTPS']) || empty($_SERVER['HTTPS']) || $_SERVER['HTTPS'] == 'off'))
-  {
-    cge_redirect::redirect_https();
-    exit;
-  }
-
 // Connect with FrontEndUsers
 $feu = $this->GetModuleInstance('FrontEndUsers');
 if( !$feu ) 
@@ -106,11 +96,6 @@ if( !$this->GetPreference('allow_anon_checkout') )
       }
   }
 
-if( encrypted_store::get($keyname) != $order_id )
-  {
-    echo $this->DisplayErrorMessage($this->Lang('error_retrieve_data'));
-    return;
-  }
 
 //
 // Get the Data
@@ -130,6 +115,12 @@ if( !$order )
 //
 if( isset($params['orders_confirmorder']) && $this->GetPreference('allow_manual_checkout',1) )
   {
+    if( encrypted_store::get($keyname) != $order_id )
+      {
+	echo $this->DisplayErrorMessage($this->Lang('error_retrieve_data'));
+	return;
+      }
+
     $order->set_status(ORDERSTATUS_CONFIRMED);
     $order->save();
 
@@ -142,6 +133,30 @@ if( isset($params['orders_confirmorder']) && $this->GetPreference('allow_manual_
 
 // Get the selected gateway module
 // and give it some information
+// $gateway_modules = cg_ecomm::get_payment_modules();
+// if( is_array($gateway_modules) )
+//   {
+//     // get enough information to display a list of gateway choices to the user.
+//     $tmp = array();
+//     for( $i = 0; $i < count($gateway_modules); $i++ )
+//       {
+// 	$name = $gateway_modules[$i];
+// 	$mod = cms_utils::get_module($name);
+// 	if( !$mod ) continue;
+
+// 	$tmp2 = array();
+// 	$tmp2['module'] = $mod;
+// 	$tmp2['prompt'] = $mod->GetFriendlyName();
+// 	$tmp2['description'] = $mod->GetDescription();
+// 	$tmp2['image'] = $mod->get_image_url();
+// 	$tmp[$name] = $tmp2;
+//       }
+
+//     $smarty->assign('gateway_modules',$tmp);
+//     $smarty->assign('formstart',$this->CreateFormStart($id,'confirm',$returnid,array('order_id'=>$order_id)));
+//     $smarty->assign('formend',$this->CreateFormEnd());
+//   }
+
 $gateway_module = cg_ecomm::get_payment_module();
 if( is_object($gateway_module) )
   {
@@ -221,13 +236,11 @@ if( is_object($gateway_module) )
 	      {
 		$sku = $item->get_item_id();
 	      }
-	    $tmp = $item->get_description();
 	    $gateway_module->AddItem($item->get_description(),
 				     $sku,
 				     $item->get_quantity(),
 				     $item->get_weight(),
-				     $item->get_net_price());
-	    
+				     $item->get_net_price());	    
 	  }
       }
 
