@@ -72,14 +72,10 @@ $order_maker->set_cart_module($cart_module);
 $order_maker->set_user_id($uid);
 $order_maker->set_address_policy($this->GetPreference('address_retrieval',order_maker::ADDR_POLICY_FEU));
 $order = $order_maker->get_order();
-if( !$order )
-  {
-    echo $this->DisplayErrorMessage($this->Lang("no_items_in_cart"));
-    return;
-  }
-if( is_object($order) )
+if( $order )
   {
     $order->set_status(ORDERSTATUS_PROPOSED);
+    
     if( $order->count_real_items() == 0 )
       {
 	// There's nothing in the cart
@@ -165,10 +161,10 @@ if ($uid !== FALSE)
       $order_maker->save_address($billing_addr);
 
       // adjust the order and make sure shipping costs are calculated.
-      if( empty($status) )
-	{
-	  $order_maker->adjust_for_shipping($order);
-	}
+//       if( empty($status) )
+// 	{
+// 	  $order_maker->adjust_for_shipping($order);
+// 	}
 
       //
       // Do database work
@@ -207,18 +203,24 @@ if ($uid !== FALSE)
 	  // pay for the crap we just ordered.
 	  //
 	  session_write_close();
-	  if( orders_helper::requires_creditcard_number() )
+	  $parms = array('order_id'=>$order->get_id);
+	  if( isset($params['lang']) )
 	    {
-	      $destpage = $this->GetPreference('paymentpage',$returnid);
-	      if( $destpage < 1 ) $destpage = $returnid;
-	      $this->Redirect($id, 'payment', $destpage, array('order_id' => $order->get_id()));
+	      $parms['lang'] = $params['lang'];
 	    }
-	  else
+	  $shipping_module = cg_ecomm::get_shipping_module();
+	  if( $shipping_module )
 	    {
-	      $destpage = $this->GetPreference('confirmpage',$returnid);
+	      // we have a shipping module.. redirect to the shipping page.
+	      $destpage = $this->GetPreference('shippingpage',$returnid);
 	      if( $destpage < 1 ) $destpage = $returnid;
-	      $this->Redirect($id, 'confirm', $destpage, array('order_id' => $order->get_id()));
+	      $this->Redirect($id,'shipping',$destpage, $parms);
 	    }
+
+	  // redirect to the confirm page.
+	  $destpage = $this->GetPreference('confirmpage',$returnid);
+	  if( $destpage < 1 ) $destpage = $returnid;
+	  $this->Redirect($id, 'confirm', $destpage, $parms);
 	}
     }
   else
