@@ -123,13 +123,17 @@ else
     $smarty->assign('status','SUCCESS');
   }
 
-// clear out cruft.
-encrypted_store::erase($cname);
-encrypted_store::erase($keyname);
-$cart_module->EraseCart('gateway-complete');
-
 // get the order.
 $order_obj = $this->GetOrder($order_id);
+$status = $order_obj->get_status();
+cms_utils::set_app_data('ecomm_orderstatus',$status);
+
+// set a variable that indicates the current order status
+// clear out cruft.
+$cart_module->EraseCart('gateway-complete');
+
+encrypted_store::erase($cname);
+encrypted_store::erase($keyname);
 
 // Display the post processing template
 // variables have already been set to smarty by ProcessGateWayResult
@@ -137,7 +141,6 @@ $order_obj = $this->GetOrder($order_id);
 $smarty->assign('order_obj',$order_obj);
 $smarty->assign('ordernumber',$order_obj->get_invoice()); // deprecated.
 $smarty->assign('transaction_id',$transaction_id);
-$status = $order_obj->get_status();
 switch( $status )
   {
   case ORDERSTATUS_PROPOSED:
