@@ -135,7 +135,7 @@ $tmp = ' LEFT JOIN
           LEFT JOIN
               (SELECT order_id, SUM(amount) AS amt_paid 
                  FROM '.cms_db_prefix().'module_orders_payments
-                WHERE (status = \'payment_approved\' OR status = \'payment_refunded\')
+                WHERE status = \'payment_approved\'
                 GROUP BY order_id) AS p
           ON a.id = p.order_id';
 $query .= $tmp;
