@@ -39,27 +39,10 @@ if( !$this->CheckPermission('Modify Site Preferences') )
     return;
   }
 
-$ccprocessing_modules = array();
-$ccprocessing_modules[$this->Lang('none')] = '-1';
 $ssl_opts = array($this->Lang('yes').'&nbsp;&nbsp;'=>1,$this->Lang('no').'&nbsp;&nbsp;'=>0);
-foreach( $gCms->modules as $onemodule )
-{
-  if( isset($onemodule['object']) )
-    {
-      $module =& $onemodule['object'];
-      if( method_exists( $module, 'HasCapability' ) )
-	{
-	  $res1 = $module->HasCapability('payment_gateway',array('baseversion'=>'1.0'));
-	  if( $res1 )
-	    {
-	      if( $module->RequiresSSL() && $module->RequiresCreditCardInfo() )
-		{
-		  $ccprocessing_modules[$module->GetFriendlyName()] = $module->GetName();
-		}
-	    }
-	}
-    }
-}
+
+$tmp = module_helper::get_modules_with_capability('payment_gateway',array('baseversion'=>'1.0.6'));
+$ccprocessing_modules = array_flip(cge_array::hash_prepend($tmp,-1,$this->Lang('none')));
 
 $smarty->assign('formstart',
 		$this->CGCreateFormStart($id,'admin_saveprefs',$returnid));
@@ -90,17 +73,6 @@ $smarty->assign('input_ordernum_prefix',
 				       $this->GetPreference('ordernum_prefix','INV'),
 				       5,5));
 
-$smarty->assign('input_allow_creditcard_entry',
-		$this->CreateInputYesNoDropdown($id,'allow_creditcard_entry',
-						$this->GetPreference('allow_creditcard_entry',0)));
-
-$smarty->assign('input_store_creditcard_data',
-		$this->CreateInputYesNoDropdown($id,'store_creditcard_data',
-						$this->GetPreference('store_creditcard_data',0)));
-$smarty->assign('input_store_creditcard_4digits',
-		$this->CreateInputYesNoDropdown($id,'store_creditcard_4digits',
-						$this->GetPreference('store_creditcard_4digits',0)));
-
 $smarty->assign('input_encryption_key',
 		$this->CreateInputText($id,'encryption_key',
 				       $this->GetPreference('encryption_key'),40,40));
@@ -109,12 +81,12 @@ $contentops =& $gCms->GetContentOperations();
 $smarty->assign('input_billingpage',
 		$contentops->CreateHierarchyDropdown('',
 		     $this->GetPreference('billingpage'),$id.'billingpage'));
+$smarty->assign('input_shippingpage',
+		$contentops->CreateHierarchyDropdown('',
+		     $this->GetPreference('shippingpage'),$id.'shippingpage'));
 $smarty->assign('input_confirmpage',
 		$contentops->CreateHierarchyDropdown('',
 		     $this->GetPreference('confirmpage'),$id.'confirmpage'));
-$smarty->assign('input_paymentpage',
-		$contentops->CreateHierarchyDropdown('',
-		     $this->GetPreference('paymentpage'),$id.'paymentpage'));
 $smarty->assign('input_invoicepage',
 		$contentops->CreateHierarchyDropdown('',
 		     $this->GetPreference('invoicepage'),$id.'invoicepage'));
@@ -134,8 +106,6 @@ $smarty->assign('input_admin_invoice_template',
 							     'invoice_',
 							     $this->GetPreference('admin_invoice_template',$tmp)));
 
-$smarty->assign('input_forcessl',
-		$this->CreateInputRadioGroup($id, 'force_ssl', $ssl_opts, $this->GetPreference('force_ssl',0)));
 $smarty->assign('input_gateway_description',
 		$this->CreateInputText($id,'gateway_description',
 				       $this->GetPreference('gateway_description'),40,255));
@@ -144,8 +114,6 @@ $smarty->assign('datastore_timeout',$this->GetPreference('datastore_timeout',10)
 $smarty->assign('input_allow_anon_checkout',
 		$this->CreateInputYesNoDropdown($id,'allow_anon_checkout',
 						$this->GetPreference('allow_anon_checkout',0)));
-$smarty->assign('allow_manual_checkout',
-		$this->GetPreference('allow_manual_checkout',1));
 
 echo $this->ProcessTemplate('prefs_tab.tpl');
 	       
