@@ -14,6 +14,7 @@ $lang['addedit_confirmorder_template'] = 'Add/Edit Confirm Order Template';
 $lang['addedit_gateway_complete_template'] = 'Add/Edit Gateway Complete Template';
 $lang['addedit_invoice_template'] = 'Add/Edit Invoice Template';
 $lang['addedit_paymentform_template'] = 'Add/Edit Payment Form Template';
+$lang['addedit_shippingform_template'] = 'Add/Edit Shipping Form Template';
 $lang['address1'] = 'Address Line 1';
 $lang['address2'] = 'Address Line 2';
 $lang['address_handling'] = 'Address Handling';
@@ -23,13 +24,11 @@ $lang['admin_email_template'] = 'Admin Email Template';
 $lang['amount'] = 'Amount';
 $lang['amt_due'] = 'Amt. Due';
 $lang['any'] = 'Any';
-$lang['ask_confirm_refund'] = 'Are you sure that you want to refund the selected amount to the customers creditcard';
 $lang['ask_delete'] = 'Are you sure you want to delete this item?';
 $lang['ask_delete_order'] = 'Are you sure you want to delete this order.  It is not normally recommended to delete orders.?  Note: This will not cancel any active subscriptions.';
 $lang['ask_delete_payment'] = 'Are you sure you want to permanently remove all records of this payment?';
 $lang['ask_edit_billing'] = 'Are you sure you want to modify the billing information for this order as specified above?';
 $lang['ask_manual_payment'] = 'Are you sure you want to process a manual payment to the credit card for this amount?';
-$lang['ask_refund_payment'] = 'Are you sure you want to refund this payment in its entirety?';
 $lang['ask_saveprefs'] = 'Are you sure you want to adjust the preferences of this module?\nUse caution, incorrect adjustments may break a working website.';
 $lang['ask_setorderstatus'] = 'A possible order status change has been detected, would you like to set the status to: ';
 
@@ -103,6 +102,7 @@ $lang['dflt_gateway_complete_template'] = 'Default &quot;Gateway Transaction Com
 $lang['dflt_invoice_message'] = 'Thank you for shopping with {sitename}.';
 $lang['dflt_invoice_template'] = 'Default Invoice Template';
 $lang['dflt_paymentform_template'] = 'Default Payment Form Template';
+$lang['dflt_shippingform_template'] = 'Default Shipping Form Template';
 $lang['discount'] = 'Discount';
 
 # E
@@ -121,14 +121,11 @@ $lang['error_encryption_problem'] = 'A problem occurred encrypting or decrypting
 $lang['error_gateway_invalid_data'] = 'Could not confirm data validity from payment gateway module';
 $lang['error_insufficientparams'] = 'A required parameter was missing';
 $lang['error_invalid_address'] = 'The address you specified for &quot;%s&quot; is invalid.  Please ensure that all required fields are completed.';
-$lang['error_invalid_refundamount'] = 'The amount specified for refund is invalid (it cannot exceed the amount paid on this order)';
 $lang['error_invalidfield'] = 'The following field is invalid: %s';
 $lang['error_invalidgateway'] = 'The selected gateway module is invalid for this purpose';
 $lang['error_missingshippinginfo'] = 'Insufficient shipping information supplied';
 $lang['error_namexists'] = 'An item with that name already exists';
 $lang['error_nocartmodule'] = 'Could not find a Cart module.  Please make sure that a cart module is installed, and selected in the Products module preferences.';
-$lang['error_noccgateway'] = 'No Credit Card Processing Gateway Selected';
-$lang['error_noccmodule'] = 'Could not find the selected Credit Card Processing Module';
 $lang['error_noemailaddress'] = 'No email address has been associated with this userid';
 $lang['error_nomsgtemplates'] = 'No message templates found';
 $lang['error_nofeumodule'] = 'Could not find the FrontEndUsers module';;
@@ -148,7 +145,6 @@ $lang['error_save'] = 'Error Saving a data item: %s';
 $lang['error_security_key'] = 'The encryption key for this transaction could not be retrieved';
 $lang['error_paymentgateway_incompatible'] = 'The selected payment gateway is incompatible with this order processing module.  Please contact the site administrator';
 $lang['error_permissiondenied'] = 'Permission Denied';
-$lang['error_gatewayproblem'] = 'Error occurred communicating with gateway';
 $lang['error_unknownstatus'] = 'Received an unknown status from the payment gateway';
 $lang['error_usernotingroup'] = 'The currently logged in user is not a member of the required group';
 $lang['export_orders'] = 'Export Orders';
@@ -181,10 +177,7 @@ $lang['help'] = <<<EOT
 <p>This module works in conjunction with the Cart module.  Create a page, call it "Checkout" and set it's content should be "{Orders}".  This page will start the Checkout process.</p>
 <h3><span style="color: red;">Warning - Credit Card Information</span></h3>
 <p>It is not recommended that you use the credit card number gathering mechanism unless using a secure communications mechanism and only on secured, dedicated hosts.  There is no guarantee that the database numbers (though a simple encryption mechanism is used) are not vulnerable to theft.</p>
-<h3>Privacy Related Information:</h3>
-<p>This module uses cookies to store information required to access temporary order information on the server.  It does not transmit order information.</p>
-<p>Additionally, site administrators can enable storing the users billing information in a cookie for the use of repeat customers.  "This name and contact information is tored in an unencrypted cookie.</p>
-<p>After version 1.12.5 of this module the address data that is stored in a cookie is encrypted.</p>
+
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
@@ -231,7 +224,6 @@ $lang['info_allow_manual_checkout'] = 'If Enabled, the default template (and opt
 $lang['info_billingpage'] = '<strong>Note:</strong> This preference, and the others like it are used to allow the administrator to use different CMSMS pages for the different forms.  If &quot;none&quot; is specified, then the current page will be used.';
 $lang['info_ccprocessing_module'] = 'This module is used for manual credit card processing';
 $lang['info_coupon_code'] = 'Enter a coupon code for a possible discount';
-$lang['info_datastore_timeout'] = 'This value specifies the maximum amount of time (in minutes) that transaction information, and user entered data will remain in the database.  This time limit should be large enough to reasonably allow most users to checkout, including returning from the payment gateway, but should not be overly large for security and user convenience purposes.';
 $lang['info_default_templates'] = 'This form controls the content of the template when you click \'New Template\' in the \'Confirmation Form Templates\' tab.  Editing the text here will have no immediate effect on the appearance of your site';
 $lang['info_edit_report_template'] = 'These templates determine the style and layout for a particular report';
 $lang['info_encryption_key'] = 'This key is randomly generated when the module is installed.  Use caution when changing this value if there are already orders in the system.';
@@ -242,12 +234,10 @@ $lang['info_invoicepage'] = '<strong>Note:</strong> This page is also used as th
 $lang['info_item_string'] = 'Find orders that have items matching the specified string.  Do not use this with the invoice filter above.';
 $lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
 $lang['info_order_notes'] = 'Supply some special notes for this order';
-$lang['info_refund_amount'] = 'Enter the amount to be refunded as a positive number.<br/>This value cannot exceed the amount owing on the order (order total - payments + refunds ).';
 $lang['info_require_membergroup'] = 'This setting only applies if NOT allowing anonymous users to perform checkout';
 $lang['info_setup_events'] = 'On occasion, when upgrading the modules in different orders events handlers are not always setup properly.  Click this button to ensure all event handlers are enabled';
 $lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
 $lang['info_store_creditcard_data'] = '<strong>Note: <span style="color: red;">Not Recommended</span></strong> This information is stored in the database.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
-$lang['info_store_creditcard_4digits'] = '<strong>Recommended</strong> Store only the last 4 digits of the credit card number.  This mechanism may be used to allow storing enough information to allow processing refunds and credits to customers without compromising security';
 $lang['info_useremail_template'] = 'This template controls the layout and content of the email that is sent to the user when a new order is submitted';
 $lang['info_validcountries'] = 'Specify a list of country codes and country names (one entry per line) for the countries that will show up in the address list.  i.e: US=United States.  If no value is specified, the default country list will be used.';
 $lang['info_validstates'] = 'Specify a list of state codes and names (one entry per line) for the states or provinces that will show up in the address list.  i.e: AB=Alberta.  If no value is specified, the default state list will be used.';
@@ -293,8 +283,6 @@ $lang['msg_payment_pending'] = 'Payment pending for order %s';
 $lang['msg_payment_received'] = 'Payment %s (%s) was received for order %s';
 $lang['msg_payment_removed'] = 'Payment removed from the order';
 $lang['msg_payment_setbackwards'] = 'Attempted to set status of order %s backwards from PAID to PENDING';
-$lang['msg_transactionrefunded'] = 'Transaction Refunded';
-$lang['msg_transactionvoided'] = 'Transaction Voided';
 
 # N
 $lang['name'] = 'Name';
@@ -342,9 +330,7 @@ $lang['payment_notprocessed'] = 'Not Processed';
 $lang['payment_options'] = 'Payment Options';
 $lang['payment_other'] = 'Other';
 $lang['payment_pending'] = 'Pending';
-$lang['payment_refunded'] = 'Refunded';
 $lang['payment_status'] = 'Payment Status';
-$lang['payment_voided'] = 'Voided';
 $lang['pending'] = 'Pending';
 $lang['phone'] = 'Phone';
 $lang['popup_new_window'] = 'Popup invoice in new window';
@@ -356,10 +342,8 @@ $lang['preferences'] = 'Preferences';
 $lang['prevpage'] = '&lt;';
 $lang['price'] = 'Price';
 $lang['print_invoice'] = 'Print This Invoice';
-$lang['process_cc_now'] = 'Process CreditCard Now';
 $lang['procede_manual_checkout'] = 'Procede with Manual Checkout';
 $lang['process_manual_payment'] = 'Process Manual Payment';
-$lang['process_manual_refund'] = 'Refund Custom Amount';
 $lang['process_new_transaction'] = 'Process CreditCard Transaction through Gateway';
 $lang['process_order'] = 'Process Order';
 $lang['product_id'] = 'Product ID';
@@ -394,9 +378,9 @@ $lang['prompt_permit_deletion'] = 'Allow deletion of orders';
 $lang['prompt_requirepostal'] = 'Postal/Zip code is a required field on the billing form';
 $lang['prompt_requirestate'] = 'State/Province is a required field in the billing form';
 $lang['prompt_setup_events'] = 'Setup Gateway Events';
+$lang['prompt_shippingpage'] = 'Page to use for the shipping form';
 $lang['prompt_skip_invoice_page'] = 'Skip Invoice Page';
 $lang['prompt_store_creditcard_data'] = 'Permanently Store CreditCard Information';
-$lang['prompt_store_creditcard_4digits'] = 'Store only the last 4 digits';
 $lang['prompt_template'] = 'Message Template';
 $lang['prompt_username'] = 'Username';
 $lang['prompt_validcountries'] = 'Valid Countries:';
@@ -409,8 +393,6 @@ $lang['quantity'] = 'Quantity';
 # R
 $lang['really_uninstall'] = 'Are you sure you really want to do this? Any data associated with this module will be lost if you procede';
 $lang['records_matching_query'] = 'Number of records matching your query';
-$lang['refund'] = 'Issue Refund';
-$lang['refund_amount'] = 'Refund Amount';
 $lang['regex'] = 'Regular Expression';
 $lang['remember_last_address_used'] = 'Use the address from the last order';
 $lang['report'] = 'Report';
@@ -436,6 +418,7 @@ $lang['shipped'] = 'Shipped';
 $lang['shipping'] = 'Shipping';
 $lang['shipping_address'] = 'Shipping Address';
 $lang['shipping_costs'] = 'Shipping Costs';
+$lang['shipping_form_templates'] = 'Shipping Form Templates';
 $lang['shipping_info'] = 'Shipping Information';
 $lang['shipping_info_for'] = 'Shipping Address For';
 $lang['shipping_info_if_different'] = 'Shipping Information <em>(If different from billing information)</em>';
@@ -471,7 +454,6 @@ $lang['title_first_page'] = 'Go to the first page';
 $lang['title_last_page'] = 'Go to the last page';
 $lang['title_manage_order'] = 'Manage Order';
 $lang['title_manual_process'] = 'Manual Transaction Processing';
-$lang['title_manual_refund'] = 'Issue a Refund';
 $lang['title_next_page'] = 'Go to the next page';
 $lang['title_prev_page'] = 'Go to the previous page';
 $lang['title_useremail_template'] = 'User Email Template';
@@ -499,7 +481,6 @@ $lang['view_messages'] = 'View Messages relating to this order';
 # W
 $lang['warning_https'] = '<strong>Warning!</strong> You are not using a secure (https) connection.  It is not recommended that you continue with this action without a secure connection.';
 $lang['warning_manual_process'] = '<strong>Warning!</strong> This screen allows manual processing of credit card transactions using an online gateway.  Use caution!';
-$lang['warning_manual_refund'] = '<strong>Warning!</strong> This form allows submitting a refund that is not the full amount of the transaction.  This refund, if successful will be stored as another payment record in this order.  It is possible to corrupt the order status using this operation.  <strong>Use with Caution</strong>';
 $lang['warning_orderstatus_paid'] = '<strong>Warning!</strong> - This order has already been paid.  You should not be processing a manual payment on this order';
 $lang['warning_orderstatus_cancelled'] = '<strong>Warning!</strong> - This order has been cancelled.  You should not be processing a manual payment on this order';
 $lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
