@@ -31,6 +31,7 @@ $lang['back_to_orders'] = 'zur&uuml;ck zu den Bestellungen';
 $lang['backorder'] = 'im R&uuml;ckstand';
 $lang['balancedue'] = 'f&auml;lliger Restbetrag (teilweise bezahlt)';
 $lang['bill_to'] = 'Rechnung stellen an';
+$lang['billing'] = 'Rechnungen';
 $lang['billing_address'] = 'Rechnungsadresse';
 $lang['billing_form_templates'] = 'Rechnungsformularvorlage';
 $lang['billing_info'] = 'Rechnungsinformation';
@@ -46,15 +47,18 @@ $lang['cc_Discover'] = 'Herausfinden';
 $lang['cc_MasterCard'] = 'Mastercard';
 $lang['cc_Visa'] = 'Visa';
 $lang['city'] = 'Ort';
+$lang['company'] = 'Firma';
 $lang['completed'] = 'vollendet';
 $lang['completion_templates'] = 'Vollendungsvorlage';
 $lang['confirmed'] = 'best&auml;tigt';
 $lang['confirm_order'] = 'Bitte best&auml;tigen sie ihre Bestellung';
 $lang['confirmation_form_templates'] = 'Best&auml;tigungsformularvorlage';
 $lang['confirmation_num'] = 'Best&auml;tigungsnummer';
+$lang['cookie'] = 'Im Cookie gespeicherte Adresse verwenden';
 $lang['country'] = 'Land';
 $lang['coupon_code'] = 'Couponschl&uuml;ssel';
 $lang['created'] = 'angelegt';
+$lang['created_by'] = 'Angelegt von';
 $lang['create_invoice'] = 'Rechnung f&uuml;r diese Bestellung erstellen';
 $lang['create_invoice_for'] = 'Rechnung f&uuml;r Bestellung %s erstellen';
 $lang['creditcard'] = 'Kreditkarte';
@@ -64,9 +68,19 @@ $lang['creditcard_type'] = 'Kreditkartentyp';
 $lang['creditcard_verifycode'] = 'Verifizierungsschl&uuml;ssel';
 $lang['customer_name'] = 'Kundenname';
 $lang['date'] = 'Datum';
+$lang['date_range'] = 'Datumsbereich';
+$lang['dateopt_exactdates'] = 'Eingegebener Zeitraum';
+$lang['dateopt_7days'] = 'Letzte 7 Tage';
+$lang['dateopt_14days'] = 'Letzte 14 Tage';
+$lang['dateopt_30days'] = 'Letzte 30 Tage';
+$lang['dateopt_3months'] = 'Letzte 3 Monate';
+$lang['dateopt_6months'] = 'Letzte 6 Monate';
+$lang['dateopt_1year'] = 'Letztes Jahr';
 $lang['default_templates'] = 'Standardvorlagen';
 $lang['delete'] = 'L&ouml;schen';
+$lang['delivered'] = 'Zugestellt';
 $lang['description'] = 'Beschreibung';
+$lang['desc_order_by'] = 'Sortiere nach {$billing->get_firstname()} {$billing->get_lastname()}';
 $lang['destinations'] = 'Ziele';
 $lang['details'] = 'Details';
 $lang['dflt_billingform_template'] = 'Standard-Rechnungsformularvorlage';
@@ -79,6 +93,8 @@ $lang['dflt_paymentform_template'] = 'Standardzahlungsformularvorlage';
 $lang['discount'] = 'Erm&auml;&szlig;igung';
 $lang['edit'] = 'Bearbeiten';
 $lang['edit_billing_info'] = 'Rechnungsinformationen bearbeiten';
+$lang['edit_report_template'] = 'Bearbeite Template f&amp;uuml;r Report: %s';
+$lang['end_date'] = 'Enddatum';
 $lang['email'] = 'E-Mail';
 $lang['email_address'] = 'E-Mail-Adresse';
 $lang['email_invoice'] = 'diese Rechnung per E-Mail an den Kunden und autorisierte Administratoren senden';
@@ -105,10 +121,11 @@ $lang['error_orderinvalid'] = 'Es gibt ein Problem mit der Bestellung (die Infor
 $lang['error_ordernotfound'] = 'Die angeforderte Bestellung wurde nicht gefunden.';
 $lang['error_orderprocessing'] = 'W&auml;hrend des Bestellprozesses ist ein Fehler aufgetreten.';
 $lang['error_paymentnotfound'] = 'Die angegebene Bezahlung wurde nicht gefunden.';
+$lang['error_possible_hack'] = 'Potentieller Hack entdeckt: Ihre Benutzerkennung (%s) stimmt nicht mit der Kennung (%s) der Bestellung %s &amp;uuml;berein.  Bitte wenden Sie sich an den System Administrator.';
 $lang['error_requiressl'] = 'Das ausgew&auml;hlte Gateway f&uuml;r diese Seite ben&ouml;tigt eine verschl&uuml;sselte Verbindung, welche noch nicht vorhanden ist.';
 $lang['error_retrieve_data'] = 'Beim Versuch, die entsprechenden Informationen von der Datanbank abzufragen, ist ein Fehler aufgetreten.';
 $lang['error_save'] = 'Ein Fehler ist bei der Speicherung der folgenden Dateneinheit aufgetreten: %s';
-$lang['error_security_key'] = 'Der The Kodierungsschl&uuml;ssel f&uuml;r diese Transaktion wurde nicht &uuml;bermittelt.';
+$lang['error_security_key'] = 'Der Kodierungsschl&uuml;ssel f&uuml;r diese Transaktion wurde nicht &uuml;bermittelt.';
 $lang['error_paymentgateway_incompatible'] = 'Das ausgew&auml;hlte Gateway-Modul ist nicht kompatibel mit dieser Bestellverwaltung. Bitte kontaktieren Sie Ihren Administrator.';
 $lang['error_permissiondenied'] = 'Erlaubnis verweigert';
 $lang['error_unknownstatus'] = 'Ich habe keinen bekannten Status von der Zahlungsschnittstelle erhalten.';
@@ -119,6 +136,7 @@ $lang['first_name'] = 'Vorname';
 $lang['firstpage'] = '<<';
 $lang['friendlyname'] = 'Bestellungsverwaltung';
 $lang['from'] = 'von';
+$lang['gateway'] = 'Gateway';
 $lang['gateway_module'] = 'Zahlungsschnittstellenmodul';
 $lang['gateway_complete_templates'] = 'Zahlungsschnittstellen-Vollendungsvorlage';
 $lang['gateway_failure_message'] = 'Ihre Transaktion wurde leider nicht vollendet. Entweder wurde der Vorgang abgebrochen oder ein anderer Fehler ist aufgetreten. Bitte best&auml;tigen sie ihre Zahlungsinformationen und versuchen sie es erneut. Zu ihrer Sicherheit wurde ihr Warenkorb geleert. Entschuldigung f&uuml;r eventuelle Unannehmlichkeiten.';
@@ -170,20 +188,26 @@ $lang['id'] = 'ID';
 $lang['incomplete'] = 'unvollendet (teilweise versandt)';
 $lang['info_admin_invoice_template'] = 'eine Vorlage w&auml;hlen, die f&uuml;r das Fenster mit druckfreundlicher Rechnungsanzeige verwendet wird, wenn eine Bestellung verwaltet wird';
 $lang['info_adminemail_template'] = 'In diesem Template kann das Layout und der Inhalt der EMail festgelegt werden, die bei einer neuen Bestellung an den Administrator gesendet wird.';
+$lang['info_allow_anon_checkout'] = 'Wird diese Option deaktiviert muss der Benutzer einen g&uuml;ltigen FrontEndUsers Login besitzen um eine Bestellung abzuschlie&szlig;en';
 $lang['info_allow_creditcard_entry'] = 'Einige Payment Gateways erfordern eine Eingabe von Kreditkarten-Daten, bevor diese Daten an die Zahlungsschnittstelle &uuml;bertragen werden. Kreditkarten-Daten werden tempor&auml;r in einem verschl&uuml;sselten Format gespeichert, bis der Bestellprozess abgeschlossen oder abgebrochen wurde. Eine wiederkehrende Bereinigung der tempor&auml;ren Daten stellt sicher, dass diese Daten nicht dauerhaft auf dem Server gespeichert werden, au&szlig;er Sie aktivieren die Option, dass Kreditkartendaten gespeichert werden <em>(nicht empfohlen)</em>.';
-$lang['info_billingpage'] = '<strong>Achtung:</strong> Diese Einstellungen sowie andere wie diese, werden benutzt, dass der Administrator verschiedene CMSms Seiten f&uuml;r die verschiedenen Formulare verwenden kann. Wenn &quot;keine&quot; gew&auml;hlt ist, wird die aktuelle Seite verwendet.';
+$lang['info_billingpage'] = '<strong>Achtung:</strong> Diese Einstellungen sowie andere wie diese, erlauben dem Administrator verschiedene CMSms Seiten f&uuml;r die verschiedenen Formulare zu verwenden. Wenn &quot;keine&quot; gew&auml;hlt ist, wird die aktuelle Seite verwendet.';
 $lang['info_ccprocessing_module'] = 'Dieses Modul wird f&uuml;r die manuelle Kreditkartenbearbeitung verwendet';
 $lang['info_coupon_code'] = 'Bitte geben sie einen Couponschl&uuml;ssel f&uuml;r eine Erm&auml;&szlig;igung ein.';
 $lang['info_default_templates'] = 'Dieses Template wird verwendet, wenn Sie auf &quot;Neues Template&quot; im Reiter &quot;Best&auml;tigungs-Formular Template&quot; klicken. Wenn Sie diesen Text &auml;ndern, wird dies keinen Effekt auf die aktuelle Ausgabe der Webseite haben.';
+$lang['info_edit_report_template'] = 'Diese Templates legen Stil und Layout eines Reports fest.';
 $lang['info_encryption_key'] = 'Dieser Code wurde via Zufalls-Prinzip erzeugt, als dieses Modul installiert wurde. Wenn Sie diesen Wert &auml;ndern und bereits Bestellungen vorliegen, k&ouml;nnen Probleme auftreten.';
 $lang['info_forcessl'] = '<strong>Achtung: Empfohlen</strong>. Wenn Sie Kunden erlauben, ihre Kreditkarten-Daten anzugeben, sollten Sie diese Option aktivieren. Damit wird die &Uuml;bertragung via SSL verschl&uuml;sselt, um die Kreditkartendaten sicher zu &uuml;bertragen.';
 $lang['info_gateway_description'] = 'Diese Information wird f&uuml;r jede Transaktion zum Payment-Gateway &uuml;bertragen. Sie kann benutzt werden f&uuml;r den Name, der auf der Kreditkartenabrechnung der Kunden stehen soll.';
+$lang['info_incomplete_timeout'] = 'Offene Bestellungen die die gesetzte Zeit in Minuten nicht bearbeitet wurden k&ouml;nnen automatisch auf unvollendet gesetzt werden.  Setzen Sie den Wert auf 0 um die Funktion zu deaktivieren.';
 $lang['info_invoicepage'] = '<strong>Achtung:</strong> Diese Seite wird auch als Erfolgs- und Fehlerseite f&uuml;r die Payment Gateways verwendet.';
-$lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
+$lang['inform_no_cc_processing'] = 'Sind Sie  sich bewusst, dass Sie  bereits vorhandene Zahlungsinformationen bearbeiten?\nEs wird keine neue Kreditkarten-Transaktion verarbeitet.';
 $lang['info_order_notes'] = 'Anmerkungen zu dieser Bestellung.';
+$lang['info_require_membergroup'] = 'Diese Einstellung wird nur ber&uuml;cksichtigt, wenn Kunden NICHT anonym bestellen k&ouml;nnen.';
 $lang['info_skip_invoice_page'] = 'Wenn die Nutzer Zahlungsdaten angeben sollen, sollen diese dann auf die Rechnungsseite weitergeleitet werden, oder direkt zur Transaktions-Best&auml;tigungs-Seite?';
 $lang['info_store_creditcard_data'] = '<strong>Achtung: <span style=&quot;color: red;&quot;>Nicht empfohlen</span></strong> Die Kreditkarten-Daten werden bei Aktivierung dieser Option in der Datenbank gespeichert.<br/>Obwohl die Daten verschl&uuml;sselt gespeichert werden,<br/>wird diese Einstellung nicht empfohlen.<br/>Besser ist es, ein kompatibles Zahlungsmodul zu verwenden.';
 $lang['info_useremail_template'] = 'In diesem Template kann das Layout und der Inhalt der EMail festgelegt werden, die bei einer neuen Bestellung an den Kunde gesendet wird.';
+$lang['info_validcountries'] = 'Geben Sie eine Liste der L&auml;ndercodes und L&auml;ndernamen ein, die im Adresseingabeformular angezeigt werden sollen (ein Eintrag pro Zeile). Bsp.: US=Vereinigte  Staaten von Amerika. Wenn Sie nichts eingeben, wird die Standard-L&auml;nderliste verwendet.';
+$lang['info_validstates'] = 'Geben Sie eine Liste der K&uuml;rzel und Namen f&uuml;r Bundesstaaten oder Provinzen ein, die im Adresseingabeformular angezeigt werden sollen (ein Eintrag pro Zeile). Bsp.: AB=Alberta. Wenn Sie nichts eingeben, wird die Standard-Bundesstaatenliste verwendet.';
 $lang['info_use_integer'] = 'Nur ganzzahlige Werte verwenden';
 $lang['interval_oneday'] = 'Ein Tag';
 $lang['interval_onemonth'] = 'Ein Monat';
@@ -200,19 +224,26 @@ $lang['last_name'] = 'Nachname';
 $lang['last_modified'] = 'zuletzt bearbeitet';
 $lang['lastpage'] = '>>';
 $lang['lbl_back'] = 'zur&uuml;ck';
+$lang['lbl_preferences'] = 'Einstellungen';
 $lang['lbl_templates'] = 'Vorlagen';
+$lang['legend_dates'] = 'Zeitraum w&auml;hlen';
+$lang['legend_reports'] = 'Reporte';
 $lang['message'] = 'Nachricht';
 $lang['message_templates'] = 'Nachrichtenvorlagen';
 $lang['method'] = 'Methode';
 $lang['moddescription'] = 'Ein einfaches Modul zur Bearbeitung von Bestellungen';
 $lang['modified'] = 'ge&auml;ndert';
+$lang['msg_async_transaction'] = 'Handled Async Transcation %s for order %s';
 $lang['msg_order_cancelled'] = 'Bestellung %s abgebrochen oder abgewiesen';
 $lang['msg_order_error'] = 'Bei der Bestellung %s ist ein Fehler aufgetreten';
 $lang['msg_order_payment'] = 'Bezahlung f&uuml;r Bestellung %s erhalten.';
 $lang['msg_order_pending'] = 'Bestellungsstatus bei %s zu &bdquo;ausstehend&ldquo; ge&auml;ndert.';
-$lang['msg_order_setbackwards'] = 'Attempted to set status of order %s backwards from PAID to PENDING';
-$lang['msg_async_transaction'] = 'Handled Async Transcation %s for order %s';
+$lang['msg_payment_cancelled'] = 'Zahlung %s f&uuml;r Bestellung %s wurde abgebrochen';
+$lang['msg_payment_declined'] = 'Zahlung %s f&uuml;r Bestellung %s wurde abgelehnt';
+$lang['msg_payment_error'] = 'W&auml;hrend Zahlung %s f&uuml;r Bestellung %s trat ein Fehler auf';
+$lang['msg_payment_received'] = 'Zahlung %s (%s) f&uuml;r Bestellung %s erhalten';
 $lang['msg_payment_removed'] = 'Bezahlung von der Bestellung entfernt';
+$lang['msg_payment_setbackwards'] = 'Es wurde versucht, den Status der Bestellung% s von GEZAHLT auf OFFEN zur&uuml;ckzusetzen';
 $lang['name'] = 'Name';
 $lang['net'] = 'Netto';
 $lang['net_price'] = 'Nettopreis';
@@ -221,6 +252,7 @@ $lang['next'] = 'weiter';
 $lang['nextpage'] = '>';
 $lang['no'] = 'nein';
 $lang['no_items_in_cart'] = 'Es sind keine Artikel im Warenkorb. Bitte f&uuml;gen sie welche hinzu bevor sie zur Kasse gehen.';
+$lang['no_report_data'] = 'Keine passenden Daten gefunden';
 $lang['none'] = 'keine Vorgabe';
 $lang['notcancelledshipped'] = 'alles au&szlig;er versandt und abgebrochen';
 $lang['notes'] = 'Bemerkungen';
@@ -246,6 +278,7 @@ $lang['payment_declined'] = 'abgewiesen';
 $lang['payment_error'] = 'Fehler';
 $lang['payment_form_templates'] = 'Zahlungsformularvorlagen';
 $lang['payment_gateway_settings'] = 'Einstellungen der Zahlungsschnittstelle';
+$lang['payment_history'] = 'Bisherige Zahlungen';
 $lang['payment_info'] = 'Zahlungsinformationen';
 $lang['payment_method'] = 'Zahlungsmethode';
 $lang['payment_notprocessed'] = 'nicht bearbeitet';
@@ -274,15 +307,20 @@ $lang['promotions_settings'] = 'Werbeeinstellungen';
 $lang['prompt_address_property_map'] = 'Eigenschaften aus FrontEndUsers verwenden';
 $lang['prompt_address_retrieval'] = 'Art der Adressabfrage';
 $lang['prompt_admin_invoice_template'] = 'Vorlage f&uuml;r druckfreundliche Rechnung';
+$lang['prompt_allow_anon_checkout'] = 'Erlaube Kunden anonym (ohne FEU Login) zu bestellen.';
 $lang['prompt_allow_creditcard_entry'] = 'Kunden die Angabe von Kreditkarteninformationen erlauben';
 $lang['prompt_billingpage'] = 'Seite zur Darstellung des Rechnungsformulars &ndash; &uuml;blicherweise ist dies die Seite mit dem <code>{Orders}</code>-Tag.';
 $lang['prompt_ccprocessing_module'] = 'Kreditkartenbearbeitungsschnittstelle';
 $lang['prompt_confirmpage'] = 'Seite, die f&uuml;r das Best&auml;tigungsformular verwendet werden soll';
+$lang['prompt_datastore_timeout'] = 'Verfallszeitraum f&uuml;r tempor&auml;re Transaktionsdaten';
 $lang['prompt_date_search_type'] = 'zeige Eintr&auml;ge';
+$lang['prompt_dflt_country'] = 'Vorgabe Land';
+$lang['prompt_dflt_state'] = 'Vorgabe Bundesstaat';
 $lang['prompt_email'] = 'E-Mail-Adresse';
 $lang['prompt_encryption_key'] = 'Verschl&uuml;sselungscode';
 $lang['prompt_forcessl'] = 'Weiterleiten zu HTTPS f&uuml;r die Eingabe der Zahlungs-Informationen.';
 $lang['prompt_gateway_description'] = 'Beschreibung, welche an den Payment Gateway gesendet wird.';
+$lang['prompt_incomplete_timeout'] = 'Setze den Bestellstatus automatisch nach N Minuten auf unvollendet <em>(bei offenen Bestellungen)</em>';
 $lang['prompt_invoice_message'] = 'Nachricht, die am Anfang aller Rechnungen erscheinen soll';
 $lang['prompt_invoicepage'] = 'Seite, die f&uuml;r die Rechnungsansicht verwendet werden soll';
 $lang['prompt_of'] = 'Von';
@@ -291,17 +329,26 @@ $lang['prompt_page'] = 'Seite';
 $lang['prompt_pagelimit'] = 'Anzahl der Bestellungen pro Seite';
 $lang['prompt_paymentpage'] = 'Seite, die f&uuml;r das Zahlungsformular verwendet werden soll';
 $lang['prompt_permit_deletion'] = 'erlaube das L&ouml;schen von Bestellungen';
-$lang['prompt_process_cc_now'] = 'Kreditkartenzahlung bearbeiten';
+$lang['prompt_requirepostal'] = 'Postleitzahl im Rechnungsformular als Pflichtfeld anzeigen';
+$lang['prompt_requirestate'] = 'Bundesstaat/Provinz im Rechnungsformular als Pflichtfeld anzeigen';
 $lang['prompt_skip_invoice_page'] = 'Rechnungsseite &uuml;berspringen';
 $lang['prompt_store_creditcard_data'] = 'Kreditkarten-Daten dauerhaft speichern';
 $lang['prompt_template'] = 'Nachrichtenvorlage';
 $lang['prompt_username'] = 'Benutzername';
+$lang['prompt_validcountries'] = 'Erlaubte L&auml;nder:';
+$lang['prompt_validstates'] = 'Erlaubte Bundesstaaten:';
 $lang['proposed'] = 'noch unvollendet';
 $lang['quantity'] = 'Menge';
 $lang['really_uninstall'] = 'Sind sie sicher, dass sie dies tun wollen? Jegliche Daten, die mit diesem Modul verkn&uuml;pft sind werden verloren gehen, wenn sie fortfahren.';
 $lang['records_matching_query'] = 'Anzahl der Ergebnisse, die zu Ihrer Anfrage gefunden wurden';
 $lang['regex'] = 'regul&auml;rer Ausdruck';
 $lang['remember_last_address_used'] = 'Die Adresse der letzten Bestellung verwenden';
+$lang['report'] = 'Report';
+$lang['reports'] = 'Reports';
+$lang['report_recent_payments'] = 'K&uuml;rzlich erfolgte Zahlungen';
+$lang['report_shipping_costs'] = 'Versandkosten';
+$lang['report_subscr_picklist'] = 'Subscription Picklist';
+$lang['report_templates'] = 'Report Templates';
 $lang['return'] = 'zur&uuml;ck';
 $lang['require_group_membership'] = 'Um eine Bestellung auszuf&uuml;hren, muss ein Kunde in dieser FrontEndUser-Gruppe angemeldet sein.';
 $lang['security_settings'] = 'Sicherheits-Einstellungen';
@@ -315,19 +362,26 @@ $lang['ship_to'] = 'versenden an';
 $lang['shipped'] = 'versandt';
 $lang['shipping'] = 'Versandkosten';
 $lang['shipping_address'] = 'Versandadresse';
+$lang['shipping_costs'] = 'Versandkosten';
 $lang['shipping_info'] = 'Versandinformation';
+$lang['shipping_info_for'] = 'Lieferadresse f&uuml;r';
 $lang['shipping_info_if_different'] = 'Versandinformationen <span>(falls anders als Rechnungsinformationen)</span>';
 $lang['shipping_message'] = 'Nachricht f&uuml;r dieses Ziel';
 $lang['shipping_module'] = 'Versandmodul';
 $lang['shipping_settings'] = 'Versandeinstellungen';
 $lang['shipping_total'] = 'Gesamtsumme Versandkosten';
+$lang['sku'] = 'Art.-Nr';
+$lang['source'] = 'Quelle';
 $lang['special_instructions'] = 'spezielle Anweisungen';
+$lang['start_date'] = 'Startdatum';
 $lang['state/province'] = 'Staat/Provinz <small>(falls aus USA/Kanada)</small>';
 $lang['status'] = 'Status';
+$lang['subscription'] = 'Vorbestellung';
 $lang['subject'] = 'Betreff';
 $lang['submit'] = 'Absenden';
 $lang['submitted'] = 'Abgesandt';
 $lang['submit_payment_info'] = 'Zahlungsinformationen eingeben';
+$lang['subscribed'] = 'vorbestellt';
 $lang['subtotal'] = 'Zwischensumme';
 $lang['tax'] = 'Steuer';
 $lang['tax_module'] = 'Steuer-Modul';
@@ -335,6 +389,7 @@ $lang['tax_settings'] = 'Steuereinstellungen';
 $lang['template'] = 'Vorlage';
 $lang['template_name'] = 'Vorlagenname';
 $lang['thank_you_for_order'] = 'Vielen Dank f&uuml;r den Einkauf bei {sitename}';
+$lang['timeout'] = 'Zeit&uuml;berschreitung';
 $lang['title_adminemail_template'] = 'Administrator-E-Mail-Vorlage';
 $lang['title_first_page'] = 'Erste Seite anzeigen';
 $lang['title_last_page'] = 'Letzte Seite anzeigen';
@@ -361,16 +416,15 @@ $lang['view_message'] = 'Nachricht ansehen';
 $lang['view_messages'] = 'Nachrichten f&uuml;r diese Bestellung ansehen';
 $lang['warning_https'] = '<strong>Warnung!</strong> Sie benutzen keine verschl&uuml;sselte (https) Verbindung. Es ist nciht empfohlen, ohne eine verschl&uuml;sselte Verbindung fortzufahren.';
 $lang['warning_manual_process'] = '<strong>Warnung!</strong> Diese Ansicht erlaubt eine manuelle Verarbeitung von Kreditkarten-Transaktionen &uuml;ber ein Online-Gateway. Seien Sie vorsichtig!';
-$lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
-$lang['warning_order_paid_in_full'] = '<strong>Warning!</strong> This order already appears to have been paid in full.';
 $lang['warning_orderstatus_paid'] = '<strong>Warnung!</strong> - Diese Bestellung wurde bereits bezahlt. Sie sollten nicht mit einer Zahlung f&uuml;r diese Bestellung fortfahren.';
 $lang['warning_orderstatus_cancelled'] = '<strong>Warnung!</strong> - Diese Bestellung wurde abgebrochen. Sie sollten nicht mit einer Zahlung f&uuml;r diese Bestellung fortfahren.';
+$lang['warning_no_ccprocessing_gateway'] = '<strong>Warnung!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
+$lang['warning_order_paid_in_full'] = '<strong>Warnung!</strong> Diese Bestellung scheint bereits voll bezahlt zu sein.';
 $lang['weight'] = 'Gewicht';
 $lang['within'] = 'innerhalb';
 $lang['yes'] = 'Ja';
-$lang['qca'] = '1249923764-15871878-96895245';
-$lang['utmz'] = '156861353.1262275556.52.4.utmccn=(organic)|utmcsr=google|utmctr=cms made simple page blocks|utmcmd=organic';
-$lang['utma'] = '156861353.4340126149939662000.1247151222.1266616756.1266619520.65';
+$lang['qca'] = 'P0-1362779760-1309265682636';
+$lang['utma'] = '156861353.1681295217.1311961821.1312221772.1312224790.5';
+$lang['utmz'] = '156861353.1311961821.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
