@@ -1,4 +1,9 @@
 <?php
+$lang['0_product'] = 'Produit';
+$lang['1_service'] = 'Service ';
+$lang['2_discount'] = 'Promo';
+$lang['3_shipping'] = 'Exp&eacute;dition';
+$lang['4_tax'] = 'Taxe';
 $lang['addedit_billingform_template'] = 'Ajouter/Modifier un gabarit de formulaire de facture';
 $lang['addedit_completion_template'] = 'Ajouter/Modifier un gabarit de fin de commande';
 $lang['addedit_confirmorder_template'] = 'Ajouter/Modifier un gabarit de confirmation de commande';
@@ -7,17 +12,26 @@ $lang['addedit_invoice_template'] = 'Ajouter/Modifier un gabarit de Facture';
 $lang['addedit_paymentform_template'] = 'Ajout ou &eacute;dition d&#039;un gabarit formulaire de paiement';
 $lang['address1'] = 'Adresse, ligne 1';
 $lang['address2'] = 'Adresse, ligne 2';
+$lang['address_handling'] = 'Gestion de l&#039;adresse';
 $lang['add_msg_template'] = 'Ajouter un gabarit de message';
 $lang['admin_email_addresses'] = 'Liste (s&eacute;par&eacute;e par des virgules) d&#039;adresses email d&#039;admin &agrave; qui envoyer un mail lors d&#039;une nouvelle commande';
 $lang['admin_email_template'] = 'Gabarit de l&#039;email &agrave; l&#039;admin';
+$lang['amount'] = 'Montant';
+$lang['amt_due'] = 'Montant d&ucirc;';
 $lang['any'] = 'Tous';
 $lang['ask_delete'] = 'Voulez-vous vraiment supprimer cet &eacute;l&eacute;ment ?';
 $lang['ask_delete_order'] = 'Voulez-vous vraiment supprimer cette commande ? Il est en g&eacute;n&eacute;ral d&eacute;conseill&eacute; de supprimer des commandes.';
+$lang['ask_delete_payment'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer toutes les informations de ce paiement ?';
 $lang['ask_edit_billing'] = 'Voulez-vous vraiment modifier les informations de facturation comme indiqu&eacute; ci-dessus ?';
+$lang['ask_manual_payment'] = '&Ecirc;tes-vous s&ucirc;r de vouloir proc&eacute;der &agrave; un paiement manuel par carte de cr&eacute;dit pour ce montant ?';
+$lang['ask_saveprefs'] = '&Ecirc;tes-vous s&ucirc;r de vouloir modifier les pr&eacute;f&eacute;rences de ce module ?\nSoyez prudent : un param&eacute;trage incorrect peut rendre votre site inutilisable.';
+$lang['ask_setorderstatus'] = 'Un changement possible de statut a &eacute;t&eacute; d&eacute;tect&eacute;. Voulez-vous modifier le statut vers :';
 $lang['back'] = 'Retour';
 $lang['back_to_orders'] = 'Retour aux commandes';
 $lang['backorder'] = 'Retard&eacute;e';
+$lang['balancedue'] = 'Paiement partiel';
 $lang['bill_to'] = 'Facturer &agrave;';
+$lang['billing'] = 'Facturation';
 $lang['billing_address'] = 'Adresse de facturation';
 $lang['billing_form_templates'] = 'Gabarits de formulaire de facturation';
 $lang['billing_info'] = 'Informations de facturation';
@@ -27,26 +41,48 @@ $lang['cancelled'] = 'Annul&eacute;';
 $lang['captcha_title'] = 'Texte Captcha';
 $lang['cart_module'] = 'Module Panier';
 $lang['cart_settings'] = 'Pr&eacute;f&eacute;rences du Panier';
+$lang['cash'] = 'Liquide';
 $lang['cc_AMEX'] = 'American Express ';
 $lang['cc_Discover'] = 'Discover ';
 $lang['cc_MasterCard'] = 'Mastercard ';
 $lang['cc_Visa'] = 'Visa ';
 $lang['city'] = 'Ville';
+$lang['company'] = 'Entreprise';
 $lang['completed'] = 'Termin&eacute;e';
 $lang['completion_templates'] = 'Gabarits de commandes termin&eacute;es';
 $lang['confirmed'] = 'Confirm&eacute;e';
 $lang['confirm_order'] = 'Confirmez votre commande';
 $lang['confirmation_form_templates'] = 'Gabarits Formulaire de confirmation';
 $lang['confirmation_num'] = 'Code de confirmation';
+$lang['cookie'] = 'Utiliser l&#039;adresse stock&eacute;e dans un cookie';
 $lang['country'] = 'Pays';
+$lang['coupon_code'] = 'Code de r&eacute;duction';
 $lang['created'] = 'Cr&eacute;&eacute;e';
+$lang['created_by'] = 'Cr&eacute;e par';
 $lang['create_invoice'] = 'Cr&eacute;er une facture pour cette commande';
 $lang['create_invoice_for'] = 'Cr&eacute;er une facture pour la commande %s';
+$lang['creditcard'] = 'Carte de cr&eacute;dit';
 $lang['creditcard_expiry'] = 'Date d&#039;expiration de la carte de cr&eacute;dit';
 $lang['creditcard_number'] = 'Num&eacute;ro de la carte de cr&eacute;dit';
 $lang['creditcard_type'] = 'Type de la carte de cr&eacute;dit';
 $lang['creditcard_verifycode'] = 'Code de v&eacute;rification';
 $lang['customer_name'] = 'Nom du client';
+$lang['date'] = 'Date ';
+$lang['date_range'] = 'Intervalle de dates';
+$lang['dateopt_exactdates'] = 'Dates exactes';
+$lang['dateopt_7days'] = '7 derniers jours';
+$lang['dateopt_14days'] = '14 derniers jours';
+$lang['dateopt_30days'] = '30 derniers jours';
+$lang['dateopt_3months'] = '3 derniers mois';
+$lang['dateopt_6months'] = '6 derniers mois';
+$lang['dateopt_1year'] = 'Derni&egrave;re ann&eacute;e';
+$lang['default_templates'] = 'Gabarits par d&eacute;faut';
+$lang['delete'] = 'Supprimer';
+$lang['delivered'] = 'Livr&eacute;';
+$lang['description'] = 'Description ';
+$lang['desc_order_by'] = 'Trier par {$billing->get_firstname()} {$billing->get_lastname()}';
+$lang['destinations'] = 'Destinations ';
+$lang['details'] = 'Details ';
 $lang['dflt_billingform_template'] = 'Gabarit par d&eacute;faut Formulaire de facturation';
 $lang['dflt_confirmorder_template'] = 'Gabarit par d&eacute;faut Formulaire de confirmation';
 $lang['dflt_completion_template'] = 'Gabarit par d&eacute;faut de fin de commande';
@@ -54,21 +90,24 @@ $lang['dflt_gateway_complete_template'] = 'Gabarit par d&eacute;faut de fin de t
 $lang['dflt_invoice_message'] = 'Merci pour vos achats chez {sitename}.';
 $lang['dflt_invoice_template'] = 'Gabarit de facture par d&eacute;faut';
 $lang['dflt_paymentform_template'] = 'Gabarit par d&eacute;faut Formulaire de paiement';
-$lang['default_templates'] = 'Gabarits par d&eacute;faut';
-$lang['delete'] = 'Supprimer';
-$lang['description'] = 'Description ';
-$lang['destinations'] = 'Destinations ';
-$lang['details'] = 'Details ';
+$lang['discount'] = 'R&eacute;duction';
 $lang['edit'] = 'Modifier';
 $lang['edit_billing_info'] = 'Modifier les informations de facturation';
+$lang['edit_report_template'] = 'Modifier le gabarit pour le rapport : %s';
+$lang['end_date'] = 'Date de fin';
 $lang['email'] = 'Email ';
 $lang['email_address'] = 'Adresse email';
 $lang['email_invoice'] = 'Envoyer cette facture par e-mail au client, et aux admins autoris&eacute;s';
 $lang['email_sent_to'] = 'Email envoy&eacute; &agrave;';
 $lang['email_subject'] = 'Sujet de l&#039;email';
 $lang['error_badcaptcha'] = 'La valeur Captcha donn&eacute;e &eacute;tait incorrecte';
+$lang['error_creditcard_expired'] = 'La carte de cr&eacute;dit a expir&eacute;';
+$lang['error_encryption_problem'] = 'Un probl&egrave;me est survenu lors de l&#039;encryptage ou le d&eacute;cryptage des informations';
+$lang['error_gateway_invalid_data'] = 'Il n&#039;est pas possible de confirmer la validit&eacute; des informations issues du module de paiement';
 $lang['error_insufficientparams'] = 'Un param&egrave;tre requis est manquant';
+$lang['error_invalid_address'] = 'L&#039;adresse que vous avez entr&eacute;e pour &quot;%s&quot; est invalide. Merci de v&eacute;rifier que tous les champs requis sont renseign&eacute;s.';
 $lang['error_invalidfield'] = 'Le champ suivant n&#039;est pas valide&nbsp;: %s';
+$lang['error_invalidgateway'] = 'Le module de paiement s&eacute;lectionn&eacute; est invalide pour cette op&eacute;ration';
 $lang['error_missingshippinginfo'] = 'Les informations de livraison sont incompl&egrave;tes';
 $lang['error_namexists'] = 'Un &eacute;l&eacute;ment portant le m&ecirc;me nom existe d&eacute;j&agrave;';
 $lang['error_nocartmodule'] = 'Impossible de trouver le module Panier. V&eacute;rifiez que ce module est install&eacute; et configur&eacute; dans les pr&eacute;f&eacute;rence du module Produits';
@@ -76,9 +115,18 @@ $lang['error_noemailaddress'] = 'Aucune adresse e-mail n&#039;est disponible pou
 $lang['error_nofeumodule'] = 'Impossible de trouver le module FrontEndUsers';
 $lang['error_nopaymentgateway'] = 'La passerelle de paiement n&#039;a pas &eacute;t&eacute; configur&eacute;e';
 $lang['error_noproductsmodule'] = 'Impossible de trouver le module Produits';
+$lang['error_norequiredgroup'] = 'Merci de d&eacute;finir un groupe d&#039;utilisateurs dans l&#039;onglet de pr&eacute;f&eacute;rences';
 $lang['error_notloggedin'] = 'L&#039;utilisateur n&#039;est pas connect&eacute;';
 $lang['error_orderinvalid'] = 'Il y a un probl&egrave;me sur cette commande (informations incoh&eacute;rentes)';
 $lang['error_ordernotfound'] = 'La commande demand&eacute;e est introuvable.';
+$lang['error_orderprocessing'] = 'Une erreur est apparue lors du traitement de cette commande (soft fail)';
+$lang['error_paymentnotfound'] = 'Le paiement sp&eacute;cifi&eacute; n&#039;a pas &eacute;t&eacute; trouv&eacute;';
+$lang['error_possible_hack'] = 'Possibilit&eacute; de hack d&eacute;tect&eacute;e : votre num&eacute;ro d&#039;identifiant (%s) ne correspond pas au num&eacute;ro d&#039;identifiant (%s) trouv&eacute; pour la commande %s. Merci de contacter l&#039;administrateur du site.';
+$lang['error_requiressl'] = 'La passerelle de paiement s&eacute;lectionn&eacute;e pour ce site requiert une connexion s&eacute;curis&eacute;e qui n&#039;est pas &eacute;tablie';
+$lang['error_retrieve_data'] = 'Un probl&egrave;me est survenu lors de la r&eacute;cup&eacute;ration d&#039;informations depuis la base de donn&eacute;es';
+$lang['error_save'] = 'Erreur lors de l&#039;enregistrement d&#039;une donn&eacute;e : %s';
+$lang['error_security_key'] = 'La cl&eacute; d&#039;encryptage de cette transaction n&#039;a pas &eacute;t&eacute; r&eacute;cup&eacute;r&eacute;e';
+$lang['error_paymentgateway_incompatible'] = 'La passerelle de paiement s&eacute;lectionn&eacute;e est incompatible avec ce module de traitement de commandes. Merci de contacter votre administrateur';
 $lang['error_permissiondenied'] = 'Permission refus&eacute;e';
 $lang['error_unknownstatus'] = 'La passerelle de paiement &agrave; renvoy&eacute; un code de retour inconnu';
 $lang['error_usernotingroup'] = 'L&#039;utilisateur connect&eacute; n&#039;est pas un membre du groupe requis';
@@ -88,10 +136,12 @@ $lang['first_name'] = 'Pr&eacute;nom';
 $lang['firstpage'] = '<<';
 $lang['friendlyname'] = 'Commandes';
 $lang['from'] = 'De';
+$lang['gateway'] = 'Passerelle';
 $lang['gateway_module'] = 'Module Passerelle de Paiement';
 $lang['gateway_complete_templates'] = 'Gabarits de fin de transaction de paiement';
 $lang['gateway_failure_message'] = 'L&#039;op&eacute;ration de paiement n&#039;a pas pu se terminer normalement. Il se peut que l&#039;op&eacute;ration aie &eacute;t&eacute; annul&eacute;e, ou qu&#039;une erreur se soit produite. Merci de v&eacute;rifier les informations de paiement que vous avez indiqu&eacute;, et de r&eacute;-essayer. Pour des raisons de s&eacute;curit&eacute;, votre panier a &eacute;t&eacute; compl&egrave;tement vid&eacute;. Merci de votre patience.';
 $lang['general_settings'] = 'Pr&eacute;f&eacute;rences G&eacute;n&eacute;rales';
+$lang['get_address_from_feu'] = 'Utiliser le profil de l&#039;utilisateur';
 $lang['help'] = '<h3>Que fait ce module ?</h3>
   <p>Ce module permet de tranformer un panier d&#039;achat en commande, et de suivre cette commande. Il demande au client les informations de facturation et de livraison, et permet:<ul>
 <li>soit d&#039;effectuer un paiement via une passerelle de paiement externe,</li>
@@ -134,6 +184,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
+$lang['help_param_invoice_prefix'] = 'Ce param&egrave;tre vous permet d&#039;entrer jusqu&#039;&agrave; 4 caract&egrave;res &agrave; utiliser en tant que pr&eacute;fixe pour la g&eacute;n&eacute;ration de num&eacute;ros de factures. Si rien n&#039;est sp&eacute;cifi&eacute;, le pr&eacute;fixe utilis&eacute; sera celui des pr&eacute;f&eacute;rences du module.';
 $lang['help_param_nocaptcha'] = 'Si ce param&egrave;tre est indiqu&eacute;, captcha sera d&eacute;sactiv&eacute;';
 $lang['help_param_template'] = 'Sp&eacute;cifie un gabarit qui n&#039;est pas le gabarit par d&eacute;faut pour l&#039;utilisation de l&#039;action par defaut';
 $lang['hold'] = 'Suspendre';
@@ -143,14 +194,26 @@ $lang['id'] = 'Id ';
 $lang['incomplete'] = 'Incompl&egrave;te (exp&eacute;dition partielle)';
 $lang['info_admin_invoice_template'] = 'Choisissez le gabarit utilis&eacute; par la fen&ecirc;tre d&#039;impression facture lors de la gestion des commandes';
 $lang['info_adminemail_template'] = 'Ce gabarit contr&ocirc;le l&#039;affichage et le contenu de l&#039;email qui est envoy&eacute; aux administrateurs autoris&eacute;s quand une nouvelle commande est pass&eacute;e.';
+$lang['info_allow_anon_checkout'] = 'Si d&eacute;sactiv&eacute;, les utilisateurs devront disposer d&#039;un compte utilisateur pour pouvoir commander';
 $lang['info_allow_creditcard_entry'] = '<strong>Note:</strong> Cest information est stock&eacute;e dans la base de donn&eacute;es.<br/>M&ecirc;me si les donn&eacute;es sensibles sont crypt&eacute;es, <br/>l&#039;utilisation de cette option est d&eacute;conseill&eacute;.<br/>Utilisez plut&ocirc;t un module passerelle de paiement compatible.';
 $lang['info_billingpage'] = '<strong>Note:</strong> Cette pr&eacute;f&eacute;rences (et celle du m&ecirc;me genre) This permettent &agrave; ladministrateur d&#039;utiliser diverses pages CMSMS pour afficher les formulaires du module.  La valeur &quot;none&quot; indique que la page courante sera utilis&eacute;e.';
+$lang['info_ccprocessing_module'] = 'Ce module est utilis&eacute; pour le traitement manuel des paiements par card de cr&eacute;dit';
+$lang['info_coupon_code'] = 'Entrez un code promo pour une &eacute;ventuelle r&eacute;duction';
 $lang['info_default_templates'] = 'Ce gabarit contr&ocirc;le le contenu du gabarit quand vous cliquez &#039;Nouveau gabarit&#039; dans l&#039;onglet &#039;Gabarits Formulaire de confirmation&#039;.  L&#039;&eacute;dition de ce texte n&#039;aura aucun effet imm&eacute;diat sur l&#039;apparence de votre site';
+$lang['info_edit_report_template'] = 'Ces gabarits g&egrave;rent le style et l&#039;affichage d&#039;un rapport';
 $lang['info_encryption_key'] = 'Cette clef est g&eacute;n&eacute;r&eacute;e al&eacute;atoirement lors de l&#039;installation du module. Si des commandes existent d&eacute;j&agrave;, prudence lorsque vous changez la valeur de la clef.';
+$lang['info_forcessl'] = '<strong>Note : recommand&eacute;</strong>. Si vous permettez &agrave; vos clients d&#039;entrer leurs informations de carte de cr&eacute;dit, vous devriez activer cette option et vous assurer que vous avez correctement configur&eacute; votre site pour l&#039;acc&egrave;s s&eacute;curis&eacute; par SSL. Ceci vous permet d&#039;&ecirc;tre s&ucirc;r que la transmission des informations de carte de cr&eacute;dit sera faite gr&acirc;ce &agrave; une connexion encrypt&eacute;e.';
+$lang['info_gateway_description'] = 'Cette information est envoy&eacute;e &agrave; la passerelle de paiement pour chaque transaction, et elle peut &eacute;galement &ecirc;tre utilis&eacute;e comme information pour les relev&eacute;s de carte de vos clients. Ceci est un gabarit Smarty, vous permettant une personnalisation de l&#039;affichage.';
+$lang['info_incomplete_timeout'] = 'Les commandes &quot;propos&eacute;es&quot; qui n&#039;ont pas d&#039;activit&eacute; depuis un certain nombre de minutes (param&eacute;trable) peuvent &ecirc;tre automatiquement marqu&eacute;es &quot;Incompl&egrave;te&quot;. Saisir &quot;0&quot; pour ne pas utiliser cette fonction.';
 $lang['info_invoicepage'] = '<strong>Note:</strong> Cette page est aussi utilis&eacute;e pour afficher le r&eacute;sultat (succ&egrave;s et &eacute;chec) d&#039;un paiement via une passerelle de paiement.';
-$lang['info_order_notes'] = 'Recommendations sp&eacute;ciales pour cette commande';
+$lang['inform_no_cc_processing'] = '&Ecirc;tes-vous conscient que vous &ecirc;tre simplement en train de modifier les informations d&#039;un paiement existant ?\nAucune nouvelle transaction ne sera r&eacute;alis&eacute;e.';
+$lang['info_order_notes'] = 'Recommandations sp&eacute;ciales pour cette commande';
+$lang['info_require_membergroup'] = 'Ce param&egrave;tre n&#039;aura d&#039;effet que si vous ne permettez PAS aux clients non-identifi&eacute;s de commander';
 $lang['info_skip_invoice_page'] = 'Si le client peut saisir les informations de paiement,<br/>le diriger ensuite vers la page de facturation,<br/>ou directement vers la page de fin de transaction ?';
+$lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This information is stored in the database.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
 $lang['info_useremail_template'] = 'Ce gabarit contr&ocirc;le l&#039;apparence et le contenu de l&#039;email qui est envoy&eacute; &agrave; un utilisateur lorsqu&#039;il passe une commande.';
+$lang['info_validcountries'] = 'Entrez une liste de codes et de noms de pays (un pays par ligne) pour les pays qui doivent &ecirc;tre pr&eacute;sent&eacute; dans le formulaire d&#039;adresse. Par exemple : FR=France. Si aucune valeur n&#039;est pr&eacute;cis&eacute;e, la liste des pays par d&eacute;faut sera affich&eacute;e.';
+$lang['info_validstates'] = 'Entrez une liste de codes et de noms d&#039;&eacute;tats (un &eacute;tat par ligne) pour les &eacute;tats ou provinces &agrave; afficher dans le formulaire d&#039;adresse. Par exemple : AB=Alberta. Si aucune valeur n&#039;est pr&eacute;cis&eacute;e, la liste des &eacute;tats par d&eacute;faut sera affich&eacute;e.';
 $lang['info_use_integer'] = 'Seuls les nombres entiers sont autoris&eacute;s';
 $lang['interval_oneday'] = 'Un jour';
 $lang['interval_onemonth'] = 'Un mois';
@@ -166,20 +229,42 @@ $lang['items'] = 'El&eacute;ments';
 $lang['last_name'] = 'Nom';
 $lang['last_modified'] = 'Derni&egrave;re modification';
 $lang['lastpage'] = '>>';
+$lang['lbl_back'] = 'Retour';
+$lang['lbl_preferences'] = 'Pr&eacute;f&eacute;rences';
+$lang['lbl_templates'] = 'Gabarits';
+$lang['legend_dates'] = 'S&eacute;lectionnez les dates';
+$lang['legend_reports'] = 'Rapports';
 $lang['message'] = 'Message ';
 $lang['message_templates'] = 'Gabarits de Message';
+$lang['method'] = 'M&eacute;thode';
 $lang['moddescription'] = 'Un module simple pour enregistrer des commandes';
 $lang['modified'] = 'Modifi&eacute;e';
+$lang['msg_async_transaction'] = 'Transaction asynchrone %s trait&eacute;e pour la commande %s';
+$lang['msg_order_cancelled'] = 'Commande %s annul&eacute;e ou refus&eacute;e';
+$lang['msg_order_error'] = 'Erreur rencontr&eacute;e pour la commande %s';
+$lang['msg_order_payment'] = 'Paiement re&ccedil;u pour la commande %s';
+$lang['msg_order_pending'] = 'Statut de commande chang&eacute; pour &amp;quot;En cours&amp;quot;';
+$lang['msg_payment_cancelled'] = 'Paiement %s annul&eacute; pour la commande %s';
+$lang['msg_payment_declined'] = 'Paiement %s refus&eacute; pour la commande %s';
+$lang['msg_payment_error'] = 'Une erreur est survenue lors du paiement %s pour la commande %s';
+$lang['msg_payment_received'] = 'Paiement %s (%s) re&ccedil;u pour la commande %s';
+$lang['msg_payment_removed'] = 'Paiement supprim&eacute; de la commande';
+$lang['msg_payment_setbackwards'] = 'Tentative de changement de statut de la commande %s : de &quot;Pay&eacute;&quot; vers &quot;En attente&quot;';
 $lang['name'] = 'Nom';
+$lang['net'] = 'Net ';
+$lang['net_price'] = 'Prix net';
 $lang['new_order_submitted'] = 'Une nouvelle commande a &eacute;t&eacute; pass&eacute;e';
 $lang['next'] = 'Suivant';
 $lang['nextpage'] = '>';
 $lang['no'] = 'Non';
 $lang['no_items_in_cart'] = 'Votre panier est vide. Veuillez y ajouter quelque chose avant de poursuivre.';
+$lang['no_report_data'] = 'Aucune donn&eacute;e correspondante trouv&eacute;e';
 $lang['none'] = 'Aucun';
 $lang['notcancelledshipped'] = 'Tout sauf annul&eacute; ou exp&eacute;di&eacute;';
+$lang['notes'] = 'Notes ';
 $lang['notshipped'] = 'Non exp&eacute;di&eacute;e';
 $lang['num'] = 'Non.';
+$lang['online'] = 'en ligne';
 $lang['order'] = 'Commande';
 $lang['orders'] = 'Commandes';
 $lang['order_confirm_form_templates'] = 'Gabarits de formulaires de confirmation de commande';
@@ -189,10 +274,25 @@ $lang['order_number'] = 'No. de commande';
 $lang['order_processing'] = 'Traitement des commandes';
 $lang['order_statistics'] = 'Statistiques des commandes';
 $lang['order_summary'] = 'R&eacute;sum&eacute; des commandes';
+$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'R&eacute;duction';
 $lang['paid'] = 'Pay&eacute;';
+$lang['payment_amount'] = 'Montant du paiement';
+$lang['payment_approved'] = 'Valid&eacute;';
+$lang['payment_cancelled'] = 'Annul&eacute;';
+$lang['payment_date'] = 'Date du paiement';
+$lang['payment_declined'] = 'Refus&eacute;';
+$lang['payment_error'] = 'Erreur';
 $lang['payment_form_templates'] = 'Gabarits de formulaires de paiement';
 $lang['payment_gateway_settings'] = 'Pr&eacute;f&eacute;rences de la passerelle de paiement';
+$lang['payment_history'] = 'Historique de paiement';
 $lang['payment_info'] = 'Informations de paiement';
+$lang['payment_method'] = 'M&eacute;thode de paiement';
+$lang['payment_notprocessed'] = 'Non trait&eacute;';
+$lang['payment_options'] = 'Options de paiement';
+$lang['payment_other'] = 'Autre';
+$lang['payment_pending'] = 'En attente';
+$lang['payment_status'] = 'Statut de paiement';
+$lang['pending'] = 'En attente';
 $lang['phone'] = 'T&eacute;l&eacute;phone';
 $lang['popup_new_window'] = 'Afficher la facture dans une nouvelle fen&ecirc;tre';
 $lang['postinstall'] = 'Le module Commandes a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
@@ -204,15 +304,29 @@ $lang['prevpage'] = '<';
 $lang['price'] = 'Prix';
 $lang['print_invoice'] = 'Imprimer cette facture';
 $lang['procede_manual_checkout'] = 'Utiliser le paiement manuel';
+$lang['process_manual_payment'] = 'Proc&eacute;der &agrave; un paiement manuel';
+$lang['process_new_transaction'] = 'Proc&eacute;der &agrave; un paiement par la passerelle de paiement';
 $lang['process_order'] = 'Passer la commande';
 $lang['product_id'] = 'ID Produit';
+$lang['promotions_module'] = 'Module de promotions';
+$lang['promotions_settings'] = 'Param&egrave;tres de promotions';
+$lang['prompt_address_property_map'] = 'Carte de correspondance entre les propri&eacute;t&eacute;s FEU et le module';
+$lang['prompt_address_retrieval'] = 'M&eacute;thode de r&eacute;cup&eacute;ration de l&#039;adresse';
 $lang['prompt_admin_invoice_template'] = 'Gabarits d&#039;impression de factures';
+$lang['prompt_allow_anon_checkout'] = 'Autoriser les clients anonymes (sans compte FEU) &agrave; commander';
 $lang['prompt_allow_creditcard_entry'] = 'Autoriser la saisie des informations de carte de cr&eacute;dit';
 $lang['prompt_billingpage'] = 'Page sur laquelle le formulaire de facturation est suppos&eacute; &ecirc;tre affich&eacute;. Il s&#039;agit g&eacute;n&eacute;ralement de la page qui comporte la balise <code>{Orders}</code>.';
+$lang['prompt_ccprocessing_module'] = 'Passerelle de paiement par carte de cr&eacute;dit';
 $lang['prompt_confirmpage'] = 'Page utilis&eacute;e pour le formulaire de confirmation';
+$lang['prompt_datastore_timeout'] = 'P&eacute;riode d&#039;expiration des informations de transaction temporaires';
 $lang['prompt_date_search_type'] = 'Filtrer les enregistrements qui sont ';
+$lang['prompt_dflt_country'] = 'Pays par d&eacute;faut';
+$lang['prompt_dflt_state'] = 'Etat par d&eacute;faut';
+$lang['prompt_email'] = 'Adresse e-mail';
 $lang['prompt_encryption_key'] = 'Clef de cryptage';
 $lang['prompt_forcessl'] = 'Rediriger la page en HTTPS pour la saisie des informations de paiement';
+$lang['prompt_gateway_description'] = 'Description &agrave; envoyer &agrave; la passerelle de paiement';
+$lang['prompt_incomplete_timeout'] = 'Modifie automatiquement le statut des commandes &agrave; &quot;Incomplet&quot; <em>(si &quot;Propos&eacute;&quot;)</em> apr&egrave;s N minutes';
 $lang['prompt_invoice_message'] = 'Message &agrave; placer en t&ecirc;te de toutes les factures';
 $lang['prompt_invoicepage'] = 'Page &agrave; utiliser pour l&#039;affichage des factures';
 $lang['prompt_of'] = 'De';
@@ -221,15 +335,29 @@ $lang['prompt_page'] = 'Page ';
 $lang['prompt_pagelimit'] = 'Nombre de commandes par page';
 $lang['prompt_paymentpage'] = 'Page utilis&eacute;e pour afficher le formulaire de paiement';
 $lang['prompt_permit_deletion'] = 'Autoriser la suppression de commandes';
+$lang['prompt_requirepostal'] = 'Le code postal est un champ obligatoire pour le formulaire de facturation';
+$lang['prompt_requirestate'] = 'L&#039;&eacute;tat / province est un champ obligatoire pour le formulaire de facturation';
 $lang['prompt_skip_invoice_page'] = 'Ignorer la page de facturation';
+$lang['prompt_store_creditcard_data'] = 'Stocker les informations de carte de cr&eacute;dit de mani&egrave;re permanente';
 $lang['prompt_template'] = 'Gabarit de message';
+$lang['prompt_username'] = 'Nom d&#039;utilisateur';
+$lang['prompt_validcountries'] = 'Pays autoris&eacute;s : ';
+$lang['prompt_validstates'] = 'Etats autoris&eacute;s : ';
 $lang['proposed'] = 'Propos&eacute;';
 $lang['quantity'] = 'Quantit&eacute;';
 $lang['really_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir continuer? Toutes les donn&eacute;es associ&eacute;es &agrave; ce module seront perdues si vous continuez';
 $lang['records_matching_query'] = 'Nombre d&#039;enregistrement trouv&eacute;s';
 $lang['regex'] = 'Expression r&eacute;guli&egrave;re';
+$lang['remember_last_address_used'] = 'Utiliser l&#039;adresse de la derni&egrave;re commande';
+$lang['report'] = 'Rapport';
+$lang['reports'] = 'Rapports';
+$lang['report_recent_payments'] = 'Paiement r&eacute;cents';
+$lang['report_shipping_costs'] = 'Tarifs d&#039;exp&eacute;dition';
+$lang['report_subscr_picklist'] = 'Subscription Picklist';
+$lang['report_templates'] = 'Gabarits de rapport';
 $lang['return'] = 'Retour';
 $lang['require_group_membership'] = 'Requiert que tous les utilisateurs qui arrivent &agrave; l&#039;&eacute;tape de la commande soient membres de ce groupe FEU';
+$lang['security_settings'] = 'Param&egrave;tres de s&eacute;curit&eacute;';
 $lang['select_action'] = 'Choisir une action';
 $lang['select_one'] = 'Veuillez s&eacute;lectionner';
 $lang['select_invoice_template'] = 'Choisissez un gabarit de facture';
@@ -240,19 +368,26 @@ $lang['ship_to'] = 'Livraison &agrave;';
 $lang['shipped'] = 'Exp&eacute;di&eacute;';
 $lang['shipping'] = 'Exp&eacute;dition';
 $lang['shipping_address'] = 'Adresse de livraison';
+$lang['shipping_costs'] = 'Tarifs de livraison';
 $lang['shipping_info'] = 'Informations de livraison';
+$lang['shipping_info_for'] = 'Adresse d&#039;exp&eacute;dition pour';
 $lang['shipping_info_if_different'] = 'Informations de livraison <em>(si diff&eacute;rent des informations de facturation)</em>';
 $lang['shipping_message'] = 'Message concernant cette destination';
 $lang['shipping_module'] = 'Module d&#039;exp&eacute;dition';
 $lang['shipping_settings'] = 'Pr&eacute;f&eacute;rence de l&#039;exp&eacute;dition';
 $lang['shipping_total'] = 'Total des frais d&#039;ex&eacute;pdition';
+$lang['sku'] = 'SKU ';
+$lang['source'] = 'Source ';
 $lang['special_instructions'] = 'Information suppl&eacute;mentaires';
+$lang['start_date'] = 'Date de d&eacute;part';
 $lang['state/province'] = '&Eacute;tat/Province';
 $lang['status'] = 'Etat';
+$lang['subscription'] = 'Souscription';
 $lang['subject'] = 'Sujet';
 $lang['submit'] = 'Soumettre';
 $lang['submitted'] = 'Soumis';
 $lang['submit_payment_info'] = 'Envoyer les informations de paiement';
+$lang['subscribed'] = 'Souscrit';
 $lang['subtotal'] = 'Sous-total';
 $lang['tax'] = 'Taxes';
 $lang['tax_module'] = 'Modules de Taxes';
@@ -260,30 +395,42 @@ $lang['tax_settings'] = 'Pr&eacute;f&eacute;rences des taxes';
 $lang['template'] = 'Gabarit';
 $lang['template_name'] = 'Nom du gabarit';
 $lang['thank_you_for_order'] = 'Merci pour vos achats chez {sitename}';
+$lang['timeout'] = 'Expir&eacute;';
 $lang['title_adminemail_template'] = 'Gabarit de l&#039;email &agrave; l&#039;administrateur';
 $lang['title_first_page'] = 'Aller &agrave; la premi&egrave;re page';
 $lang['title_last_page'] = 'Aller &agrave; la derni&egrave;re page';
 $lang['title_manage_order'] = 'G&eacute;rer les commandes';
+$lang['title_manual_process'] = 'Traitement d&#039;une transaction manuelle';
 $lang['title_next_page'] = 'Aller &agrave; la page suivante';
 $lang['title_prev_page'] = 'Aller &agrave; la page pr&eacute;c&eacute;dente';
 $lang['title_useremail_template'] = 'Gabarit de l&#039;email &agrave; l&#039;utilisateur';
 $lang['to'] = 'A';
 $lang['total'] = 'Total ';
 $lang['tracking_num'] = 'Num&eacute;ro de suivi';
+$lang['transaction_id'] = 'Identifiant de transaction';
+$lang['transaction_successful'] = 'Paiement accept&eacute;';
+$lang['type'] = 'Type ';
 $lang['update_status'] = 'Mettre &agrave; jour le statut';
 $lang['unit_price'] = 'Prix unitaire';
 $lang['unit_weight'] = 'Poids unitaire';
+$lang['unknown'] = 'Inconnu';
 $lang['unlimited'] = 'Illimit&eacute;';
 $lang['username'] = 'Nom d&#039;utilisateur';
 $lang['user_email_template'] = 'Gabarit de l&#039;email &agrave; l&#039;utilisateur';
 $lang['view'] = 'Afficher';
 $lang['view_message'] = 'Afficher le message';
 $lang['view_messages'] = 'Afficher les messages relatifs &agrave; cette commande';
+$lang['warning_https'] = '<strong>Attention !</strong> Vous n&#039;utilisez pas de connexion s&eacute;curis&eacute;e (https). Il n&#039;est pas recommand&eacute; de continuer cette action sans une connexion s&eacute;curis&eacute;e.';
+$lang['warning_manual_process'] = '<strong>Attention !</strong> Cette interface vous permet la saisie manuelle d&#039;informations de carte de cr&eacute;dit en utilisant une plateforme de paiement. A utiliser avec pr&eacute;caution !';
+$lang['warning_orderstatus_paid'] = '<strong>Attention !</strong> Cette commande a d&eacute;j&agrave; &eacute;t&eacute; pay&eacute;e. Vous ne devriez pas proc&eacute;der &agrave; un paiement manuel sur cette commande';
+$lang['warning_orderstatus_cancelled'] = '<strong>Attention !</strong> Cette commande a &eacute;t&eacute; annul&eacute;e. Vous ne devriez pas proc&eacute;der &agrave; un paiement manuel sur cette commande';
+$lang['warning_no_ccprocessing_gateway'] = '<strong>Attention !</strong> Bien qu&#039;il vous soit possible d&#039;entrer des informations de paiement par carte pour un nouveau paiement ou un paiement existant, aucune transaction ne sera r&eacute;alis&eacute;e.';
+$lang['warning_order_paid_in_full'] = '<strong> Attention !</strong> Cette commande a d&eacute;j&agrave; &eacute;t&eacute; r&eacute;gl&eacute;e en totalit&eacute;.';
 $lang['weight'] = 'Poids';
 $lang['within'] = 'Depuis';
 $lang['yes'] = 'Oui';
-$lang['utma'] = '156861353.385745402.1236959550.1237849726.1238794631.3';
-$lang['utmz'] = '156861353.1237849726.2.2.utmcsr=calguy1000.com|utmccn=(referral)|utmcmd=referral|utmcct=/news.html';
-$lang['utmb'] = '156861353.1.10.1238794631';
+$lang['utmz'] = '156861353.1301379144.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1385159307.1301379144.1301572522.1301577918.3';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
