@@ -418,21 +418,25 @@ class order_maker
 
     if( !$cart_items ) return FALSE;
 
-    $shipping_cost = $module->CalculateShipping($cart_items);
-    if( $shipping_cost !== FALSE )
+    if( method_exists($module,'CalculateShipping') )
       {
-	$line_item = new line_item();
-	$line_item->set_quantity(1);
-	$line_item->set_item_type(line_item::ITEMTYPE_SHIPPING);
-	if( is_array($shipping_cost) )
+	// old (deprecated) method.
+	$shipping_cost = $module->CalculateShipping($cart_items);
+	if( $shipping_cost !== FALSE )
 	  {
-	    $line_item->set_decription($shipping_cost[0]);
-	    $line_item->set_unit_price($shipping_cost[1]);
-	  }
-	else
-	  {
-	    $line_item->set_description($this->_this_module->Lang('shipping'));
-	    $line_item->set_unit_price($shipping_cost);
+	    $line_item = new line_item();
+	    $line_item->set_quantity(1);
+	    $line_item->set_item_type(line_item::ITEMTYPE_SHIPPING);
+	    if( is_array($shipping_cost) )
+	      {
+		$line_item->set_decription($shipping_cost[0]);
+		$line_item->set_unit_price($shipping_cost[1]);
+	      }
+	    else
+	      {
+		$line_item->set_description($this->_this_module->Lang('shipping'));
+		$line_item->set_unit_price($shipping_cost);
+	      }
 	  }
       }
     return $line_item;
@@ -539,15 +543,6 @@ class order_maker
 	return $order;
       }
 
-    // now get the stuff out of the cart into the order.
-    $basket_names = $this->_cart_module->GetBasketNames($this->_uid);
-    if( !is_array($basket_names) || count($basket_names) <= 0 )
-      {
-	// no baskets, so no order.
-	return $order;
-      }
-
-
     // start building the order
     $order = new orders_order();
     $order->set_feu_user($this->_uid);
@@ -567,30 +562,18 @@ class order_maker
       {
 	if( isset($_COOKIE['my_address']) )
 	  {
-	    if( startswith('e:',$data) )
-	      {
-		// encrypted
-		$orders = cms_utils::get_module('Orders');
-		$data = substr($_COOKIE['my_address'],2);
-		$data = base64_decode($data);
-		$data = cge_encrypt::decrypt($orders->GetPreference('encryption_key'),$data);
-		$billing_addr = unserialize($data);
-	      }
-	    else
-	      {
-		// old style, not encrypted.
-		$data = unserialize(base64_decode($_COOKIE['my_address']));
-		$billing_addr = unserialize(base64_decode($_COOKIE['my_address']));
-	      }
+	    $billing_addr = unserialize(base64_decode($_COOKIE['my_address']));
 	  }
       }
 
-    if( !is_object($billing_addr) )
+    if( !$billing_addr )
       {
 	$billing_addr = new orders_address();
       }
     $order->set_billing($billing_addr);
 
+    // now get the stuff out of the cart into the order.
+    $basket_names = $this->_cart_module->GetBasketNames($this->_uid);
     foreach( $basket_names as $one_basket_name )
       {
 	$basket_details = $this->_cart_module->GetBasketDetails($one_basket_name,$this->_uid);
@@ -654,11 +637,8 @@ class order_maker
   {
     if( $this->_billing_address_policy == order_maker::ADDR_POLICY_COOKIE )
       {
-	$orders = cms_utils::get_module('Orders');
-	$data = cge_encrypt::encrypt($orders->GetPreference('encryption_key'),serialize($address));
-	if( !$data ) return;
-	$data = base64_encode($data);
-	@setcookie('my_address','e:'.$data,time()+(365*24*60*60));
+	$data = base64_encode(serialize($address));
+	@setcookie('my_address',$data,time()+(365*24*60*60));
       }
   }
 } // end of class
