@@ -45,7 +45,7 @@ class orders_gateway_helper
     if( !$order_id ) 
       return $orders_mod->Lang('error_orderinvalid');
     $order_obj = orders_ops::load_by_id($order_id);
-    if( !is_object($order_obj) ) return 'error_orderinvalid';
+    if( !is_object($order_obj) ) return $this->Lang('error_orderinvalid');
 
     $uid = $trans->get_user_id();
     $transaction_id = $trans->get_id();
@@ -249,16 +249,9 @@ class orders_gateway_helper
 		    $order_obj->set_status(ORDERSTATUS_PAID);
 		  }
 	      }
-	    else if( $all_paid )
+	    else if( $subscr_only )
 	      {
-		if( $subscr_only )
-		  {
-		    $order_obj->set_status(ORDERSTATUS_SUBSCRIBED);
-		  }
-		else
-		  {
-		    $order_obj->set_status(ORDERSTATUS_PAID);
-		  }
+		$order_obj->set_status(ORDERSTATUS_SUBSCRIBED);
 	      }
 	    break;
 	
