@@ -49,7 +49,7 @@ class orders_helper extends module_helper
   {
     if( is_null(self::$_encryption_key) )
       {
-	$module =& self::instance();
+	$module = self::instance();
 	self::$_encryption_key = $module->_getRealEncryptionKey();
       }
     return self::$_encryption_key;
@@ -58,7 +58,7 @@ class orders_helper extends module_helper
 
   static public function can_manage_orders()
   {
-    $module =& self::instance();
+    $module = self::instance();
     if( $module->CheckPermission(ORDERS_PERM_MANAGEORDERS) )
       {
 	return TRUE;
@@ -91,12 +91,11 @@ class orders_helper extends module_helper
   {
     if( !$prefix )
       {
-	$module =& self::instance();
+	$module = self::instance();
 	$prefix = $module->GetPreference('ordernum_prefix','INV');
-	if( isset($_SESSION['invoice_prefix']) )
+	if( !is_null(self::$_invoice_prefix) )
 	  {
-	    $prefix = trim($_SESSION['invoice_prefix']);
-	    unset($_SESSION['invoice_prefix']);
+	    $prefix = self::$_invoice_prefix;
 	  }
       }
     return $prefix.sprintf('%05d',$order_id);
@@ -125,41 +124,6 @@ class orders_helper extends module_helper
   }
 
 
-  static public function requires_creditcard_number()
-  {
-    $module = self::instance();
-    $allow_creditcard = $module->GetPreference('allow_creditcard_entry');
-    $gateway_requires_creditcard = '';
-    {
-      $gateway_module = cg_ecomm::get_payment_module();
-      if( is_object($gateway_module) )
-	{
-	  $gateway_requires_creditcard = $gateway_module->RequiresCreditCardInfo();
-	}
-    }
-    if( $allow_creditcard || $gateway_requires_creditcard ) 
-      {
-	return TRUE;
-      }
-    return FALSE;
-  }
-
-
-  static public function creditcard_requires_ssl()
-  {
-    $module = self::instance();
-    $force_ssl = $module->GetPreference('force_ssl');
-    $requires_creditcard = self::requires_creditcard_number();
-    $gateway_module = cg_ecomm::get_payment_module();
-    $gateway_requires_ssl = FALSE;
-    if( is_object($gateway_module) )
-      {
-	$gateway_requires_ssl = $gateway_module->RequiresSSL();
-      }
-    return ($force_ssl || $gateway_requires_ssl);
-  }
-
-
   static public function is_valid_user()
   {
     $module = self::instance();
@@ -210,6 +174,71 @@ class orders_helper extends module_helper
       }
     return self::$_security_key;
   }
+
+
+  /**
+   * estimate packages for shipping
+   *
+   * returns mixed ... error message or array of cg_ecomm_packaging_box items.
+   */
+  public static function estimate_packages(orders_order& $order)
+  {
+    $generator = new cg_ecomm_package_generator();
+    
+    // for each destination
+    $dests = $order->get_destinations();
+    foreach( $dests as $one_dest )
+      {
+	$items = $one_dest->get_items();
+	foreach( $items as $one_item )
+	  {
+	    // only products are shippable.
+	    if( $one_item->get_item_type() != line_item::ITEMTYPE_PRODUCT ) continue;
+
+	    // todo: check for unit conversion to metric
+	    $box = new cg_ecomm_packaging_box($one_item->get_id(),$one_item->get_weight(),0);
+	    $info = cg_ecomm::get_product_info($one_item->get_source(),$one_item->get_item_id());
+	    if( !is_object($info) )
+	      {
+		throw new Exception('Could not get product info for a product');
+	      }
+	    $dimensions = $info->get_dimensions();
+	    if( !$dimensions || count($dimensions) != 3 || $dimensions[0] <= 0 || $dimensions[1] <= 0 || $dimensions[2] <= 0 )
+	      {
+		audit($one_item->get_item_id(),$one_item->get_source(),'Invalid dimensions for packaging');
+		continue;
+	      }
+
+	    $box['length'] = $dimensions[0];
+	    $box['width'] = $dimensions[1];
+	    $box['height'] = $dimensions[2];
+	    $box['weight'] = $one_item->get_weight();
+
+	    // box dimensions need to be in metric (cm and kg)
+	    if( !cge_units::is_weight_metric(cg_ecomm::get_weight_units()) )
+	      {
+		$box['weight'] *= cge_units::KG_TO_LBS;
+	      }
+	    if( !cge_units::is_length_metric(cg_ecomm::get_length_units()) )
+	      {
+		$box['width'] *= cge_units::KG_TO_LBS;
+		$box['height'] *= cge_units::KG_TO_LBS;
+		$box['length'] *= cge_units::KG_TO_LBS;
+	      }
+
+	    $generator->add_item($box);
+	  }
+      }
+
+    $res = $generator->calculate();
+    if( !$res )
+      {
+	// error ooccurred
+	return $generator->get_error();
+      }
+
+    return $generator->get_packages();
+  }
 }
 
 #
