@@ -35,116 +35,9 @@
 
 class orders_ops
 {
-  protected function orders_ops() {} 
-  
-  static public function find_by_billing_email($email,$limit = null,$offset = null)
-  {
-    if( !$email ) return;
-
-    $db = cmsms()->GetDb();
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_orders WHERE billing_email = ? ORDER BY modified_date';
-    $list = null;
-    if( $limit > 1 && $offset >= 0 )
-      {
-	$list = $db->SelectLimit($query,$limit,$offset,array($email));
-      }
-    else
-      {
-	$list = $db->GetCol($query,array($email));
-      }
-    return $list;
-  }
-
-
-  static public function find_by_feu_id($feu_uid,$limit = null,$offset = null)
-  {
-    if( $feu_uid <= 0 ) return;
-
-    $db = cmsms()->GetDB();
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_orders WHERE feu_user_id = ? ORDER BY modified_date';
-    if( $limit > 1 && $offset >= 0 )
-      {
-	$list = $db->SelectLimit($query,$limit,$offset,array($feu_uid));
-      }
-    else
-      {
-	$list = $db->GetCol($query,array($feu_uid));
-      }
-    return $list;
-  }
-
-
-  /**
-   * Get a summary of order details.
-   *
-   * @param mixed order_id.  Either an integer order id.. or an array of integer order id's.
-   * @returns a hash of hashes... key of top level array is the order id... members contain information about the order.
-   */
-  static public function get_summary($order_id)
-  {
-    $qparms = array();
-    $query = 'SELECT O.id,O.invoice,O.status,I2.items,I1.weight,I1.total,(I1.total - IFNULL(P1.paid,0)) AS amtdue,O.create_date,O.modified_date 
-              FROM '.cms_db_prefix().'module_orders O
-                  LEFT JOIN (SELECT order_id, SUM(weight) AS weight,SUM(GREATEST(COALESCE(master_price,0),quantity*unit_price))+SUM(quantity*COALESCE(discount,0)) 
-                             AS total 
-                             FROM '.cms_db_prefix().'module_orders_items 
-                             GROUP BY order_id) 
-                             AS I1 ON O.id = I1.order_id
-                  LEFT JOIN (SELECT order_id, SUM(quantity) AS items 
-                             FROM '.cms_db_prefix().'module_orders_items 
-                             WHERE item_type = ? OR item_type = ?
-                             GROUP BY order_id)
-                             AS I2 ON O.id = I2.order_id
-                  LEFT JOIN (SELECT order_id,SUM(amount) AS paid
-                             FROM '.cms_db_prefix().'module_orders_payments
-                             GROUP BY order_id)
-                             AS P1 ON O.id = P1.order_id';
-    $qparms[] = '0_product';
-    $qparms[] = '1_service';
-
-    if( is_array($order_id) )
-      {
-	$tmp = array();
-	for( $i = 0; $i < count($order_id); $i++ )
-	  {
-	    if( $order_id[$i] > 0 ) $tmp[] = $order_id[$i];
-	  }
-	if( !is_array($tmp) || count($tmp) == 0 )
-	  {
-	    // nothing to query, so nuke the query var.
-	    $query = '';
-          }
-	else
-	  {
-	    $query .= ' WHERE O.id IN ('.implode(',',$tmp).')';
-	  }
-      }
-    else if( is_int($order_id) && $order_id > 0 )
-      {
-	$query .= ' WHERE O.id = ?';
-	$qparms[] = $order_id;
-      }
-    else
-      {
-	// something wierd
-	return;
-      }
-
-    if( !$query ) return;
-
-    $db = cmsms()->GetDb();
-    $tmp = $db->GetArray($query,$qparms);
-    if( is_array($tmp) && count($tmp) )
-      {
-	$results = cge_array::to_hash($tmp,'id');
-	return $results;
-      }
-  }
-
-
   static public function &find_last_feu_order($feu_uid)
   {
-    global $gCms; $db = $gCms->GetDb();
+    global $gCms; $db =& $gCms->GetDb();
     $query = 'SELECT id FROM '.cms_db_prefix().'module_orders
                WHERE feu_user_id = ?
                ORDER by id DESC LIMIT 1';
@@ -158,7 +51,7 @@ class orders_ops
   {
     // load the order record itself
     $bad = null;
-    global $gCms; $db = $gCms->GetDb();
+    global $gCms; $db =& $gCms->GetDb();
     $query = 'SELECT id, feu_user_id, invoice,
               billing_company,
               billing_first_name, billing_last_name, billing_address1,
@@ -224,7 +117,7 @@ class orders_ops
   {
     // load the order record itself
     $bad = null;
-    global $gCms; $db = $gCms->GetDb();
+    global $gCms; $db =& $gCms->GetDb();
     $query = 'SELECT id, feu_user_id, invoice,
               billing_company,
               billing_first_name, billing_last_name, billing_address1,
@@ -257,7 +150,7 @@ class orders_ops
 
     // now fill in the payments stuff
     $query = 'SELECT id FROM '.cms_db_prefix().'module_orders_payments
-               WHERE order_id = ? ORDER BY payment_date DESC';
+               WHERE order_id = ?';
     $tmp = $db->GetCol($query,array($id));
     if( is_array($tmp) )
       {
@@ -287,7 +180,7 @@ class orders_ops
 
   static public function insert(orders_order &$order)
   {
-    global $gCms; $db = $gCms->GetDb();
+    global $gCms; $db =& $gCms->GetDb();
     $now = $db->DbTimeStamp(time());
     $query = 'INSERT INTO '.cms_db_prefix()."module_orders
                (feu_user_id,invoice,
@@ -382,7 +275,7 @@ class orders_ops
 
   static public function update(orders_order &$order,$delete_items = false)
   {
-    global $gCms; $db = $gCms->GetDb();
+    global $gCms; $db =& $gCms->GetDb();
     $now = $db->DbTimeStamp(time());
     $query = 'UPDATE '.cms_db_prefix()."module_orders SET
                 feu_user_id = ?, invoice = ?, 
@@ -471,7 +364,7 @@ class orders_ops
 
   static public function delete_by_id($order_id)
   {
-    global $gCms; $db = $gCms->GetDb();
+    global $gCms; $db =& $gCms->GetDb();
 
     $query = 'DELETE FROM '.cms_db_prefix().'module_orders_messages WHERE order_id = ?';
     $db->Execute($query,array($order_id));
