@@ -44,8 +44,7 @@ class payment_ops
                      cc_expiry,
                      AES_DECRYPT(cc_verifycode, unhex(?)) AS cc_verifycode,
                      confirmation_num, txn_id, notes, assocdata
-                FROM '.cms_db_prefix().'module_orders_payments WHERE txn_id = ?
-                ORDER BY payment_date DESC';
+                FROM '.cms_db_prefix().'module_orders_payments WHERE txn_id = ?';
     $str = orders_helper::get_encryption_key();
     $row = $db->GetRow($query,array($str,$str,$id));
     if( !$row ) 
@@ -75,8 +74,7 @@ class payment_ops
                      cc_expiry,
                      AES_DECRYPT(cc_verifycode, unhex(?)) AS cc_verifycode,
                      confirmation_num, txn_id, notes, assocdata
-                FROM '.cms_db_prefix().'module_orders_payments WHERE id = ?
-                ORDER BY payment_date DESC';
+                FROM '.cms_db_prefix().'module_orders_payments WHERE id = ?';
     $str = orders_helper::get_encryption_key();
     $row = $db->GetRow($query,array($str,$str,$id));
     if( !$row ) 
