@@ -317,14 +317,32 @@ switch($current_version)
       Events::CreateEvent('Orders', 'CalculateDiscounts');
     }
 
+  case '1.10.6': /* for good measure */
+  case '1.10.7': /* for good measure */
+  case '1.10.8': /* for good measure */
   case '1.11':
   case '1.11.1':
   case '1.11.2':
-    $this->SetTemplate('useremail_template',$this->GetPreference('useremail_template'));
-    $this->SetTemplate('adminemail_template',$this->GetPreference('adminemail_template'));
-    $this->RemovePreference('useremail_template');
-    $this->RemovePreference('adminemail_template');
+    {
+      $this->SetTemplate('useremail_template',$this->GetPreference('useremail_template'));
+      $this->SetTemplate('adminemail_template',$this->GetPreference('adminemail_template'));
+      $this->RemovePreference('useremail_template');
+      $this->RemovePreference('adminemail_template');
+    }
+
+  case '1.11.3': 
+    {
+      $fn = cms_join_path(dirname(__FILE__),'templates','orig_shippingform_template.tpl');
+      if( file_exists( $fn ) )
+	{
+	  $template = file_get_contents( $fn );
+	  $this->SetPreference('systemdflt_shippingform_template',$template);
+	  $this->SetTemplate('shippingform_Sample',$template);
+	  $this->SetPreference('dflt_shippingform_template','Sample');
+	}
+    }
   }
 
+
 // EOF
 ?>
